# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/simple_table.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/simple_table.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import annotation_pb2 as zetasql_dot_public_dot_annotation__pb2
from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!zetasql/public/simple_table.proto\x12\x07zetasql\x1a\x1fzetasql/public/annotation.proto\x1a\x19zetasql/public/type.proto\":\n\x1cSimpleAnonymizationInfoProto\x12\x1a\n\x12userid_column_name\x18\x01 \x03(\t\"\xfd\x02\n\x10SimpleTableProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10serialization_id\x18\x02 \x01(\x03\x12\x16\n\x0eis_value_table\x18\x03 \x01(\x08\x12*\n\x06\x63olumn\x18\x04 \x03(\x0b\x32\x1a.zetasql.SimpleColumnProto\x12 \n\x18primary_key_column_index\x18\t \x03(\x05\x12!\n\x19row_identity_column_index\x18\x0b \x03(\x05\x12\x17\n\x0fname_in_catalog\x18\x05 \x01(\t\x12#\n\x1b\x61llow_anonymous_column_name\x18\x06 \x01(\x08\x12$\n\x1c\x61llow_duplicate_column_names\x18\x07 \x01(\x08\x12\x41\n\x12\x61nonymization_info\x18\x08 \x01(\x0b\x32%.zetasql.SimpleAnonymizationInfoProto\x12\x11\n\tfull_name\x18\n \x01(\t\"\xed\x01\n\x18\x45xpressionAttributeProto\x12\x19\n\x11\x65xpression_string\x18\x08 \x01(\t\x12I\n\x0f\x65xpression_kind\x18\t \x01(\x0e\x32\x30.zetasql.ExpressionAttributeProto.ExpressionKind\x12%\n\x19row_identity_column_index\x18\n \x03(\x05\x42\x02\x10\x01\"D\n\x0e\x45xpressionKind\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\r\n\tGENERATED\x10\x01\x12\x16\n\x12MEASURE_EXPRESSION\x10\x02\"\xbe\x02\n\x11SimpleColumnProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\x12\x18\n\x10is_pseudo_column\x18\x03 \x01(\x08\x12 \n\x12is_writable_column\x18\x04 \x01(\x08:\x04true\x12(\n can_update_unwritable_to_default\x18\x06 \x01(\x08\x12\x33\n\x0e\x61nnotation_map\x18\x05 \x01(\x0b\x32\x1b.zetasql.AnnotationMapProto\x12 \n\x11has_default_value\x18\x07 \x01(\x08:\x05\x66\x61lse\x12<\n\x11\x63olumn_expression\x18\x08 \x01(\x0b\x32!.zetasql.ExpressionAttributeProtoB\'\n\x12\x63om.google.zetasqlB\x11SimpleTableProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.simple_table_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\021SimpleTableProtos'
  _globals['_EXPRESSIONATTRIBUTEPROTO'].fields_by_name['row_identity_column_index']._loaded_options = None
  _globals['_EXPRESSIONATTRIBUTEPROTO'].fields_by_name['row_identity_column_index']._serialized_options = b'\020\001'
  _globals['_SIMPLEANONYMIZATIONINFOPROTO']._serialized_start=106
  _globals['_SIMPLEANONYMIZATIONINFOPROTO']._serialized_end=164
  _globals['_SIMPLETABLEPROTO']._serialized_start=167
  _globals['_SIMPLETABLEPROTO']._serialized_end=548
  _globals['_EXPRESSIONATTRIBUTEPROTO']._serialized_start=551
  _globals['_EXPRESSIONATTRIBUTEPROTO']._serialized_end=788
  _globals['_EXPRESSIONATTRIBUTEPROTO_EXPRESSIONKIND']._serialized_start=720
  _globals['_EXPRESSIONATTRIBUTEPROTO_EXPRESSIONKIND']._serialized_end=788
  _globals['_SIMPLECOLUMNPROTO']._serialized_start=791
  _globals['_SIMPLECOLUMNPROTO']._serialized_end=1109
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/simple_constant.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/simple_constant.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2
from zetasql.wasi._pb2.zetasql.public import value_pb2 as zetasql_dot_public_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$zetasql/public/simple_constant.proto\x12\x07zetasql\x1a\x19zetasql/public/type.proto\x1a\x1azetasql/public/value.proto\"n\n\x13SimpleConstantProto\x12\x11\n\tname_path\x18\x01 \x03(\t\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\x12\"\n\x05value\x18\x03 \x01(\x0b\x32\x13.zetasql.ValueProtoB*\n\x12\x63om.google.zetasqlB\x14SimpleConstantProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.simple_constant_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\024SimpleConstantProtos'
  _globals['_SIMPLECONSTANTPROTO']._serialized_start=104
  _globals['_SIMPLECONSTANTPROTO']._serialized_end=214
# @@protoc_insertion_point(module_scope)



"""TVFBuilder - Fluent API for building TableValuedFunction ProtoModel objects."""

from typing_extensions import Self

from zetasql.types import (
    FunctionArgumentType,
    FunctionArgumentTypeOptions,
    FunctionEnums,
    FunctionSignature,
    SignatureArgumentKind,
    TableValuedFunction,
    TVFRelation,
    TVFRelationColumn,
    Type,
    TypeKind,
)

from ._helpers import convert_to_type


class TVFBuilder:
    """Builder for TableValuedFunction ProtoModel objects.

    Args:
        name: TVF name (can be qualified like "pkg.my_tvf")
    """

    def __init__(self, name: str):
        name_path = name.split(".") if "." in name else [name]
        self._tvf = TableValuedFunction(name_path=name_path, signature=FunctionSignature(argument=[], return_type=None))
        self._tvf_type = None
        self._output_columns = []

    def add_argument(
        self,
        name: str,
        type_or_kind: Type | TypeKind | int,
        cardinality: FunctionEnums.ArgumentCardinality = FunctionEnums.ArgumentCardinality.REQUIRED,
    ) -> Self:
        """Add a scalar argument to the TVF."""
        arg_type = convert_to_type(type_or_kind)
        arg = FunctionArgumentType(
            kind=SignatureArgumentKind.ARG_TYPE_FIXED,
            type=arg_type,
            options=FunctionArgumentTypeOptions(cardinality=cardinality, argument_name=name),
        )
        self._tvf.signature.argument.append(arg)
        return self

    def add_table_argument(self, name: str) -> Self:
        """Add a TABLE argument to the TVF."""
        arg = FunctionArgumentType(
            kind=SignatureArgumentKind.ARG_TYPE_RELATION,
            options=FunctionArgumentTypeOptions(argument_name=name),
        )
        self._tvf.signature.argument.append(arg)
        return self

    def set_output_schema(self, columns: list[tuple[str, Type | TypeKind | int]]) -> Self:
        """Set fixed output schema for the TVF."""
        self._tvf_type = FunctionEnums.TableValuedFunctionType.FIXED_OUTPUT_SCHEMA_TVF
        self._output_columns = []

        for col_name, type_or_kind in columns:
            col_type = convert_to_type(type_or_kind)
            self._output_columns.append(TVFRelationColumn(name=col_name, type=col_type))

        return self

    def set_forward_input_schema(self) -> Self:
        """Set TVF to forward input schema to output (pass-through)."""
        self._tvf_type = FunctionEnums.TableValuedFunctionType.FORWARD_INPUT_SCHEMA_TO_OUTPUT_SCHEMA_TVF
        return self

    def append_output_column(self, name: str, type_or_kind: Type | TypeKind | int) -> Self:
        """Append a column to the output schema."""
        if self._tvf_type == FunctionEnums.TableValuedFunctionType.FORWARD_INPUT_SCHEMA_TO_OUTPUT_SCHEMA_TVF:
            self._tvf_type = (
                FunctionEnums.TableValuedFunctionType.FORWARD_INPUT_SCHEMA_TO_OUTPUT_SCHEMA_WITH_APPENDED_COLUMNS
            )

        col_type = convert_to_type(type_or_kind)
        self._output_columns.append(TVFRelationColumn(name=name, type=col_type))
        return self

    def set_forward_input_schema_with_appended_columns(
        self,
        appended_columns: list[tuple[str, Type | TypeKind | int]],
    ) -> Self:
        """Set TVF to forward input schema plus additional columns."""
        self._tvf_type = (
            FunctionEnums.TableValuedFunctionType.FORWARD_INPUT_SCHEMA_TO_OUTPUT_SCHEMA_WITH_APPENDED_COLUMNS
        )
        self._output_columns = []

        for col_name, type_or_kind in appended_columns:
            col_type = convert_to_type(type_or_kind)
            self._output_columns.append(TVFRelationColumn(name=col_name, type=col_type))

        return self

    def build(self) -> TableValuedFunction:
        """Build and return the TableValuedFunction ProtoModel."""
        if self._tvf_type is not None:
            self._tvf.type = self._tvf_type

        if self._output_columns:
            output_relation = TVFRelation(column=self._output_columns, is_value_table=False)
            self._tvf.signature.return_type = FunctionArgumentType(
                kind=SignatureArgumentKind.ARG_TYPE_RELATION,
                options=FunctionArgumentTypeOptions(relation_input_schema=output_relation),
            )

        return self._tvf


__all__ = ["TVFBuilder"]



"""Generated protocol buffer Python modules.

This package contains auto-generated code from .proto files.
Do not edit these files manually - they will be overwritten.

To regenerate:
    ./scripts/build_protos.sh
"""



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/options.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import builtin_function_pb2 as zetasql_dot_public_dot_builtin__function__pb2
from zetasql.wasi._pb2.zetasql.public import options_pb2 as zetasql_dot_public_dot_options__pb2
from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2
from zetasql.wasi._pb2.zetasql.resolved_ast import resolved_node_kind_pb2 as zetasql_dot_resolved__ast_dot_resolved__node__kind__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bzetasql/proto/options.proto\x12\x07zetasql\x1a%zetasql/public/builtin_function.proto\x1a\x1czetasql/public/options.proto\x1a\x19zetasql/public/type.proto\x1a-zetasql/resolved_ast/resolved_node_kind.proto\"\x97\x02\n\"ZetaSQLBuiltinFunctionOptionsProto\x12\x37\n\x10language_options\x18\x01 \x01(\x0b\x32\x1d.zetasql.LanguageOptionsProto\x12:\n\x14include_function_ids\x18\x02 \x03(\x0e\x32\x1c.zetasql.FunctionSignatureId\x12:\n\x14\x65xclude_function_ids\x18\x03 \x03(\x0e\x32\x1c.zetasql.FunctionSignatureId\x12@\n\x1a\x65nabled_rewrites_map_entry\x18\x04 \x03(\x0b\x32\x1c.zetasql.EnabledRewriteProto\"O\n\x13\x45nabledRewriteProto\x12)\n\x03key\x18\x01 \x01(\x0e\x32\x1c.zetasql.FunctionSignatureId\x12\r\n\x05value\x18\x02 \x01(\x08\"\x91\x03\n\x14LanguageOptionsProto\x12\x39\n\x14name_resolution_mode\x18\x02 \x01(\x0e\x32\x1b.zetasql.NameResolutionMode\x12*\n\x0cproduct_mode\x18\x03 \x01(\x0e\x32\x14.zetasql.ProductMode\x12\"\n\x1a\x65rror_on_deprecated_syntax\x18\x04 \x01(\x08\x12;\n\x19\x65nabled_language_features\x18\x05 \x03(\x0e\x32\x18.zetasql.LanguageFeature\x12<\n\x19supported_statement_kinds\x18\x06 \x03(\x0e\x32\x19.zetasql.ResolvedNodeKind\x12&\n\x1esupported_generic_entity_types\x18\x07 \x03(\t\x12\x19\n\x11reserved_keywords\x18\x08 \x03(\t\x12*\n\"supported_generic_sub_entity_types\x18\t \x03(\tJ\x04\x08\x01\x10\x02\"\xba\x06\n\x1b\x41llowedHintsAndOptionsProto\x12 \n\x18\x64isallow_unknown_options\x18\x01 \x01(\x08\x12-\n%disallow_unknown_hints_with_qualifier\x18\x02 \x03(\t\x12<\n\x04hint\x18\x03 \x03(\x0b\x32..zetasql.AllowedHintsAndOptionsProto.HintProto\x12@\n\x06option\x18\x04 \x03(\x0b\x32\x30.zetasql.AllowedHintsAndOptionsProto.OptionProto\x12N\n\x14\x61nonymization_option\x18\x05 \x03(\x0b\x32\x30.zetasql.AllowedHintsAndOptionsProto.OptionProto\x12U\n\x1b\x64ifferential_privacy_option\x18\x06 \x03(\x0b\x32\x30.zetasql.AllowedHintsAndOptionsProto.OptionProto\x12\'\n\x1f\x64isallow_duplicate_option_names\x18\x07 \x01(\x08\x1ai\n\tHintProto\x12\x11\n\tqualifier\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\x04type\x18\x03 \x01(\x0b\x32\x12.zetasql.TypeProto\x12\x19\n\x11\x61llow_unqualified\x18\x04 \x01(\x08\x1a\x8e\x02\n\x0bOptionProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\x12V\n\x0eresolving_kind\x18\x03 \x01(\x0e\x32>.zetasql.AllowedHintsAndOptionsProto.OptionProto.ResolvingKind\x12\x19\n\x11\x61llow_alter_array\x18\x04 \x01(\x08\"\\\n\rResolvingKind\x12+\n\'CONSTANT_OR_EMPTY_NAME_SCOPE_IDENTIFIER\x10\x00\x12\x1e\n\x1a\x46ROM_NAME_SCOPE_IDENTIFIER\x10\x01\"\xa2\x0c\n\x14\x41nalyzerOptionsProto\x12\x37\n\x10language_options\x18\x01 \x01(\x0b\x32\x1d.zetasql.LanguageOptionsProto\x12K\n\x10query_parameters\x18\x02 \x03(\x0b\x32\x31.zetasql.AnalyzerOptionsProto.QueryParameterProto\x12\x37\n\x1bpositional_query_parameters\x18\x0c \x03(\x0b\x32\x12.zetasql.TypeProto\x12M\n\x12\x65xpression_columns\x18\x03 \x03(\x0b\x32\x31.zetasql.AnalyzerOptionsProto.QueryParameterProto\x12U\n\x1ain_scope_expression_column\x18\x04 \x01(\x0b\x32\x31.zetasql.AnalyzerOptionsProto.QueryParameterProto\x12M\n\x12\x64\x64l_pseudo_columns\x18\x0f \x03(\x0b\x32\x31.zetasql.AnalyzerOptionsProto.QueryParameterProto\x12\x35\n\x12\x65rror_message_mode\x18\x06 \x01(\x0e\x32\x19.zetasql.ErrorMessageMode\x12\x18\n\x10\x64\x65\x66\x61ult_timezone\x18\x07 \x01(\t\x12\x33\n+create_new_column_for_each_projected_output\x18\x14 \x01(\x08\x12\x1c\n\x14prune_unused_columns\x18\t \x01(\x08\x12#\n\x1b\x61llow_undeclared_parameters\x18\n \x01(\x08\x12.\n\x0eparameter_mode\x18\r \x01(\x0e\x32\x16.zetasql.ParameterMode\x12G\n\x19\x61llowed_hints_and_options\x18\x0b \x01(\x0b\x32$.zetasql.AllowedHintsAndOptionsProto\x12\x34\n\x11statement_context\x18\x0e \x01(\x0e\x32\x19.zetasql.StatementContext\x12\x1f\n\x17preserve_column_aliases\x18\x11 \x01(\x08\x12K\n\x10system_variables\x18\x12 \x03(\x0b\x32\x31.zetasql.AnalyzerOptionsProto.SystemVariableProto\x12/\n\x13target_column_types\x18\x13 \x03(\x0b\x32\x12.zetasql.TypeProto\x12\x35\n\x10\x65nabled_rewrites\x18\x15 \x03(\x0e\x32\x1b.zetasql.ResolvedASTRewrite\x12\x44\n\x1aparse_location_record_type\x18\x17 \x01(\x0e\x32 .zetasql.ParseLocationRecordType\x12!\n\x19preserve_unnecessary_cast\x18\x18 \x01(\x08\x12+\n#default_anon_function_report_format\x18\x19 \x01(\t\x12 \n\x18\x64\x65\x66\x61ult_anon_kappa_value\x18\x1a \x01(\x03\x12\x30\n\x0frewrite_options\x18\x1c \x01(\x0b\x32\x17.zetasql.RewriteOptions\x12\x42\n:replace_table_not_found_error_with_tvf_error_if_applicable\x18\x1d \x01(\x08\x12/\n\'log_impact_of_lateral_column_references\x18\x1f \x01(\x08\x1a\x45\n\x13QueryParameterProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\x1aJ\n\x13SystemVariableProto\x12\x11\n\tname_path\x18\x01 \x03(\t\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProtoJ\x04\x08\x08\x10\tJ\x04\x08\x16\x10\x17J\x04\x08\x10\x10\x11J\x04\x08\x1b\x10\x1c\x42)\n\x12\x63om.google.zetasqlB\x13ZetaSQLOptionsProto')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\023ZetaSQLOptionsProto'
  _globals['_ZETASQLBUILTINFUNCTIONOPTIONSPROTO']._serialized_start=184
  _globals['_ZETASQLBUILTINFUNCTIONOPTIONSPROTO']._serialized_end=463
  _globals['_ENABLEDREWRITEPROTO']._serialized_start=465
  _globals['_ENABLEDREWRITEPROTO']._serialized_end=544
  _globals['_LANGUAGEOPTIONSPROTO']._serialized_start=547
  _globals['_LANGUAGEOPTIONSPROTO']._serialized_end=948
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO']._serialized_start=951
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO']._serialized_end=1777
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO_HINTPROTO']._serialized_start=1399
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO_HINTPROTO']._serialized_end=1504
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO_OPTIONPROTO']._serialized_start=1507
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO_OPTIONPROTO']._serialized_end=1777
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO_OPTIONPROTO_RESOLVINGKIND']._serialized_start=1685
  _globals['_ALLOWEDHINTSANDOPTIONSPROTO_OPTIONPROTO_RESOLVINGKIND']._serialized_end=1777
  _globals['_ANALYZEROPTIONSPROTO']._serialized_start=1780
  _globals['_ANALYZEROPTIONSPROTO']._serialized_end=3350
  _globals['_ANALYZEROPTIONSPROTO_QUERYPARAMETERPROTO']._serialized_start=3181
  _globals['_ANALYZEROPTIONSPROTO_QUERYPARAMETERPROTO']._serialized_end=3250
  _globals['_ANALYZEROPTIONSPROTO_SYSTEMVARIABLEPROTO']._serialized_start=3252
  _globals['_ANALYZEROPTIONSPROTO_SYSTEMVARIABLEPROTO']._serialized_end=3326
# @@protoc_insertion_point(module_scope)



from zetasql.wasi._pb2.zetasql.public import simple_value_pb2 as _simple_value_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import python_message as _python_message
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TypeParametersProto(_message.Message):
    __slots__ = ("string_type_parameters", "numeric_type_parameters", "extended_type_parameters", "timestamp_type_parameters", "child_list")
    STRING_TYPE_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    NUMERIC_TYPE_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    EXTENDED_TYPE_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_TYPE_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    CHILD_LIST_FIELD_NUMBER: _ClassVar[int]
    string_type_parameters: StringTypeParametersProto
    numeric_type_parameters: NumericTypeParametersProto
    extended_type_parameters: ExtendedTypeParametersProto
    timestamp_type_parameters: TimestampTypeParametersProto
    child_list: _containers.RepeatedCompositeFieldContainer[TypeParametersProto]
    def __init__(self, string_type_parameters: _Optional[_Union[StringTypeParametersProto, _Mapping]] = ..., numeric_type_parameters: _Optional[_Union[NumericTypeParametersProto, _Mapping]] = ..., extended_type_parameters: _Optional[_Union[ExtendedTypeParametersProto, _Mapping]] = ..., timestamp_type_parameters: _Optional[_Union[TimestampTypeParametersProto, _Mapping]] = ..., child_list: _Optional[_Iterable[_Union[TypeParametersProto, _Mapping]]] = ...) -> None: ...

class StringTypeParametersProto(_message.Message):
    __slots__ = ("max_length", "is_max_length")
    MAX_LENGTH_FIELD_NUMBER: _ClassVar[int]
    IS_MAX_LENGTH_FIELD_NUMBER: _ClassVar[int]
    max_length: int
    is_max_length: bool
    def __init__(self, max_length: _Optional[int] = ..., is_max_length: bool = ...) -> None: ...

class TimestampTypeParametersProto(_message.Message):
    __slots__ = ("precision",)
    PRECISION_FIELD_NUMBER: _ClassVar[int]
    precision: int
    def __init__(self, precision: _Optional[int] = ...) -> None: ...

class NumericTypeParametersProto(_message.Message):
    __slots__ = ("precision", "is_max_precision", "scale")
    Extensions: _python_message._ExtensionDict
    PRECISION_FIELD_NUMBER: _ClassVar[int]
    IS_MAX_PRECISION_FIELD_NUMBER: _ClassVar[int]
    SCALE_FIELD_NUMBER: _ClassVar[int]
    precision: int
    is_max_precision: bool
    scale: int
    def __init__(self, precision: _Optional[int] = ..., is_max_precision: bool = ..., scale: _Optional[int] = ...) -> None: ...

class ExtendedTypeParametersProto(_message.Message):
    __slots__ = ("parameters",)
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    parameters: _containers.RepeatedCompositeFieldContainer[_simple_value_pb2.SimpleValueProto]
    def __init__(self, parameters: _Optional[_Iterable[_Union[_simple_value_pb2.SimpleValueProto, _Mapping]]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ErrorLocation(_message.Message):
    __slots__ = ("line", "column", "filename", "input_start_line_offset", "input_start_column_offset", "error_source")
    LINE_FIELD_NUMBER: _ClassVar[int]
    COLUMN_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    INPUT_START_LINE_OFFSET_FIELD_NUMBER: _ClassVar[int]
    INPUT_START_COLUMN_OFFSET_FIELD_NUMBER: _ClassVar[int]
    ERROR_SOURCE_FIELD_NUMBER: _ClassVar[int]
    line: int
    column: int
    filename: str
    input_start_line_offset: int
    input_start_column_offset: int
    error_source: _containers.RepeatedCompositeFieldContainer[ErrorSource]
    def __init__(self, line: _Optional[int] = ..., column: _Optional[int] = ..., filename: _Optional[str] = ..., input_start_line_offset: _Optional[int] = ..., input_start_column_offset: _Optional[int] = ..., error_source: _Optional[_Iterable[_Union[ErrorSource, _Mapping]]] = ...) -> None: ...

class ErrorSource(_message.Message):
    __slots__ = ("error_message", "error_message_caret_string", "error_location")
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_CARET_STRING_FIELD_NUMBER: _ClassVar[int]
    ERROR_LOCATION_FIELD_NUMBER: _ClassVar[int]
    error_message: str
    error_message_caret_string: str
    error_location: ErrorLocation
    def __init__(self, error_message: _Optional[str] = ..., error_message_caret_string: _Optional[str] = ..., error_location: _Optional[_Union[ErrorLocation, _Mapping]] = ...) -> None: ...



from zetasql.wasi._pb2.zetasql.public import type_pb2 as _type_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class RangeSessionizeEnums(_message.Message):
    __slots__ = ()
    class RangeSessionizeMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        RANGE_SESSIONIZE_MODE_INVALID: _ClassVar[RangeSessionizeEnums.RangeSessionizeMode]
        OVERLAPS: _ClassVar[RangeSessionizeEnums.RangeSessionizeMode]
        MEETS: _ClassVar[RangeSessionizeEnums.RangeSessionizeMode]
    RANGE_SESSIONIZE_MODE_INVALID: RangeSessionizeEnums.RangeSessionizeMode
    OVERLAPS: RangeSessionizeEnums.RangeSessionizeMode
    MEETS: RangeSessionizeEnums.RangeSessionizeMode
    def __init__(self) -> None: ...



from zetasql.wasi._pb2.zetasql.proto import function_pb2 as _function_pb2
from zetasql.wasi._pb2.zetasql.proto import options_pb2 as _options_pb2
from zetasql.wasi._pb2.zetasql.proto import simple_property_graph_pb2 as _simple_property_graph_pb2
from zetasql.wasi._pb2.zetasql.public import simple_connection_pb2 as _simple_connection_pb2
from zetasql.wasi._pb2.zetasql.public import simple_constant_pb2 as _simple_constant_pb2
from zetasql.wasi._pb2.zetasql.public import simple_model_pb2 as _simple_model_pb2
from zetasql.wasi._pb2.zetasql.public import simple_sequence_pb2 as _simple_sequence_pb2
from zetasql.wasi._pb2.zetasql.public import simple_table_pb2 as _simple_table_pb2
from zetasql.wasi._pb2.zetasql.public import type_pb2 as _type_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SimpleCatalogProto(_message.Message):
    __slots__ = ("name", "table", "named_type", "catalog", "builtin_function_options", "custom_function", "custom_tvf", "file_descriptor_set_index", "procedure", "constant", "property_graph", "connection", "model", "sequence")
    class NamedTypeProto(_message.Message):
        __slots__ = ("name", "type")
        NAME_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        name: str
        type: _type_pb2.TypeProto
        def __init__(self, name: _Optional[str] = ..., type: _Optional[_Union[_type_pb2.TypeProto, _Mapping]] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    TABLE_FIELD_NUMBER: _ClassVar[int]
    NAMED_TYPE_FIELD_NUMBER: _ClassVar[int]
    CATALOG_FIELD_NUMBER: _ClassVar[int]
    BUILTIN_FUNCTION_OPTIONS_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_FUNCTION_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_TVF_FIELD_NUMBER: _ClassVar[int]
    FILE_DESCRIPTOR_SET_INDEX_FIELD_NUMBER: _ClassVar[int]
    PROCEDURE_FIELD_NUMBER: _ClassVar[int]
    CONSTANT_FIELD_NUMBER: _ClassVar[int]
    PROPERTY_GRAPH_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    name: str
    table: _containers.RepeatedCompositeFieldContainer[_simple_table_pb2.SimpleTableProto]
    named_type: _containers.RepeatedCompositeFieldContainer[SimpleCatalogProto.NamedTypeProto]
    catalog: _containers.RepeatedCompositeFieldContainer[SimpleCatalogProto]
    builtin_function_options: _options_pb2.ZetaSQLBuiltinFunctionOptionsProto
    custom_function: _containers.RepeatedCompositeFieldContainer[_function_pb2.FunctionProto]
    custom_tvf: _containers.RepeatedCompositeFieldContainer[_function_pb2.TableValuedFunctionProto]
    file_descriptor_set_index: int
    procedure: _containers.RepeatedCompositeFieldContainer[_function_pb2.ProcedureProto]
    constant: _containers.RepeatedCompositeFieldContainer[_simple_constant_pb2.SimpleConstantProto]
    property_graph: _containers.RepeatedCompositeFieldContainer[_simple_property_graph_pb2.SimplePropertyGraphProto]
    connection: _containers.RepeatedCompositeFieldContainer[_simple_connection_pb2.SimpleConnectionProto]
    model: _containers.RepeatedCompositeFieldContainer[_simple_model_pb2.SimpleModelProto]
    sequence: _containers.RepeatedCompositeFieldContainer[_simple_sequence_pb2.SimpleSequenceProto]
    def __init__(self, name: _Optional[str] = ..., table: _Optional[_Iterable[_Union[_simple_table_pb2.SimpleTableProto, _Mapping]]] = ..., named_type: _Optional[_Iterable[_Union[SimpleCatalogProto.NamedTypeProto, _Mapping]]] = ..., catalog: _Optional[_Iterable[_Union[SimpleCatalogProto, _Mapping]]] = ..., builtin_function_options: _Optional[_Union[_options_pb2.ZetaSQLBuiltinFunctionOptionsProto, _Mapping]] = ..., custom_function: _Optional[_Iterable[_Union[_function_pb2.FunctionProto, _Mapping]]] = ..., custom_tvf: _Optional[_Iterable[_Union[_function_pb2.TableValuedFunctionProto, _Mapping]]] = ..., file_descriptor_set_index: _Optional[int] = ..., procedure: _Optional[_Iterable[_Union[_function_pb2.ProcedureProto, _Mapping]]] = ..., constant: _Optional[_Iterable[_Union[_simple_constant_pb2.SimpleConstantProto, _Mapping]]] = ..., property_graph: _Optional[_Iterable[_Union[_simple_property_graph_pb2.SimplePropertyGraphProto, _Mapping]]] = ..., connection: _Optional[_Iterable[_Union[_simple_connection_pb2.SimpleConnectionProto, _Mapping]]] = ..., model: _Optional[_Iterable[_Union[_simple_model_pb2.SimpleModelProto, _Mapping]]] = ..., sequence: _Optional[_Iterable[_Union[_simple_sequence_pb2.SimpleSequenceProto, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/internal_fix_suggestion.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/internal_fix_suggestion.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.proto import internal_error_location_pb2 as zetasql_dot_proto_dot_internal__error__location__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+zetasql/proto/internal_fix_suggestion.proto\x12\x07zetasql\x1a+zetasql/proto/internal_error_location.proto\"Q\n\x10InternalFixRange\x12-\n\x05start\x18\x01 \x01(\x0b\x32\x1e.zetasql.InternalErrorLocation\x12\x0e\n\x06length\x18\x02 \x01(\x05\"N\n\x10InternalTextEdit\x12(\n\x05range\x18\x01 \x01(\x0b\x32\x19.zetasql.InternalFixRange\x12\x10\n\x08new_text\x18\x02 \x01(\t\">\n\rInternalEdits\x12-\n\ntext_edits\x18\x01 \x03(\x0b\x32\x19.zetasql.InternalTextEdit\"C\n\x0bInternalFix\x12\r\n\x05title\x18\x01 \x01(\t\x12%\n\x05\x65\x64its\x18\x02 \x01(\x0b\x32\x16.zetasql.InternalEdits\"L\n\x1bInternalErrorFixSuggestions\x12-\n\x0f\x66ix_suggestions\x18\x01 \x03(\x0b\x32\x14.zetasql.InternalFixB1\n\x12\x63om.google.zetasqlB\x1bInternalFixSuggestionProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.internal_fix_suggestion_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\033InternalFixSuggestionProtos'
  _globals['_INTERNALFIXRANGE']._serialized_start=101
  _globals['_INTERNALFIXRANGE']._serialized_end=182
  _globals['_INTERNALTEXTEDIT']._serialized_start=184
  _globals['_INTERNALTEXTEDIT']._serialized_end=262
  _globals['_INTERNALEDITS']._serialized_start=264
  _globals['_INTERNALEDITS']._serialized_end=326
  _globals['_INTERNALFIX']._serialized_start=328
  _globals['_INTERNALFIX']._serialized_end=395
  _globals['_INTERNALERRORFIXSUGGESTIONS']._serialized_start=397
  _globals['_INTERNALERRORFIXSUGGESTIONS']._serialized_end=473
# @@protoc_insertion_point(module_scope)



from zetasql.wasi._pb2.zetasql.public import type_pb2 as _type_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class RoundingMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    ROUNDING_MODE_UNSPECIFIED: _ClassVar[RoundingMode]
    ROUND_HALF_AWAY_FROM_ZERO: _ClassVar[RoundingMode]
    ROUND_HALF_EVEN: _ClassVar[RoundingMode]
ROUNDING_MODE_UNSPECIFIED: RoundingMode
ROUND_HALF_AWAY_FROM_ZERO: RoundingMode
ROUND_HALF_EVEN: RoundingMode



from zetasql.wasi._pb2.zetasql.public import simple_table_pb2 as _simple_table_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SimpleModelProto(_message.Message):
    __slots__ = ("id", "name", "input", "output")
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    id: int
    name: str
    input: _containers.RepeatedCompositeFieldContainer[_simple_table_pb2.SimpleColumnProto]
    output: _containers.RepeatedCompositeFieldContainer[_simple_table_pb2.SimpleColumnProto]
    def __init__(self, id: _Optional[int] = ..., name: _Optional[str] = ..., input: _Optional[_Iterable[_Union[_simple_table_pb2.SimpleColumnProto, _Mapping]]] = ..., output: _Optional[_Iterable[_Union[_simple_table_pb2.SimpleColumnProto, _Mapping]]] = ...) -> None: ...



from zetasql.wasi._pb2.zetasql.public.proto import type_annotation_pb2 as _type_annotation_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/error_location.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/error_location.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#zetasql/public/error_location.proto\x12\x07zetasql\"\xb5\x01\n\rErrorLocation\x12\x0f\n\x04line\x18\x01 \x01(\x05:\x01\x31\x12\x11\n\x06\x63olumn\x18\x02 \x01(\x05:\x01\x31\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x1f\n\x17input_start_line_offset\x18\x05 \x01(\x05\x12!\n\x19input_start_column_offset\x18\x06 \x01(\x05\x12*\n\x0c\x65rror_source\x18\x04 \x03(\x0b\x32\x14.zetasql.ErrorSource\"x\n\x0b\x45rrorSource\x12\x15\n\rerror_message\x18\x01 \x01(\t\x12\"\n\x1a\x65rror_message_caret_string\x18\x02 \x01(\t\x12.\n\x0e\x65rror_location\x18\x03 \x01(\x0b\x32\x16.zetasql.ErrorLocationB\x14\n\x12\x63om.google.zetasql')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.error_location_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasql'
  _globals['_ERRORLOCATION']._serialized_start=49
  _globals['_ERRORLOCATION']._serialized_end=230
  _globals['_ERRORSOURCE']._serialized_start=232
  _globals['_ERRORSOURCE']._serialized_end=352
# @@protoc_insertion_point(module_scope)



from zetasql.wasi._pb2.zetasql.public import simple_value_pb2 as _simple_value_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AnnotationProto(_message.Message):
    __slots__ = ("id", "value")
    ID_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    id: int
    value: _simple_value_pb2.SimpleValueProto
    def __init__(self, id: _Optional[int] = ..., value: _Optional[_Union[_simple_value_pb2.SimpleValueProto, _Mapping]] = ...) -> None: ...

class AnnotationMapProto(_message.Message):
    __slots__ = ("is_null", "annotations", "array_element", "struct_fields")
    IS_NULL_FIELD_NUMBER: _ClassVar[int]
    ANNOTATIONS_FIELD_NUMBER: _ClassVar[int]
    ARRAY_ELEMENT_FIELD_NUMBER: _ClassVar[int]
    STRUCT_FIELDS_FIELD_NUMBER: _ClassVar[int]
    is_null: bool
    annotations: _containers.RepeatedCompositeFieldContainer[AnnotationProto]
    array_element: AnnotationMapProto
    struct_fields: _containers.RepeatedCompositeFieldContainer[AnnotationMapProto]
    def __init__(self, is_null: bool = ..., annotations: _Optional[_Iterable[_Union[AnnotationProto, _Mapping]]] = ..., array_element: _Optional[_Union[AnnotationMapProto, _Mapping]] = ..., struct_fields: _Optional[_Iterable[_Union[AnnotationMapProto, _Mapping]]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PropertyGraphProto(_message.Message):
    __slots__ = ("catalog", "schema", "name", "node_tables", "edge_tables", "labels", "property_declarations")
    CATALOG_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    NODE_TABLES_FIELD_NUMBER: _ClassVar[int]
    EDGE_TABLES_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    PROPERTY_DECLARATIONS_FIELD_NUMBER: _ClassVar[int]
    catalog: str
    schema: str
    name: str
    node_tables: _containers.RepeatedCompositeFieldContainer[GraphElementTableProto]
    edge_tables: _containers.RepeatedCompositeFieldContainer[GraphElementTableProto]
    labels: _containers.RepeatedCompositeFieldContainer[GraphElementLabelProto]
    property_declarations: _containers.RepeatedCompositeFieldContainer[GraphPropertyDeclarationProto]
    def __init__(self, catalog: _Optional[str] = ..., schema: _Optional[str] = ..., name: _Optional[str] = ..., node_tables: _Optional[_Iterable[_Union[GraphElementTableProto, _Mapping]]] = ..., edge_tables: _Optional[_Iterable[_Union[GraphElementTableProto, _Mapping]]] = ..., labels: _Optional[_Iterable[_Union[GraphElementLabelProto, _Mapping]]] = ..., property_declarations: _Optional[_Iterable[_Union[GraphPropertyDeclarationProto, _Mapping]]] = ...) -> None: ...

class GraphElementTableProto(_message.Message):
    __slots__ = ("name", "kind", "base_catalog_name", "base_schema_name", "base_table_name", "key_columns", "label_names", "property_definitions", "dynamic_label_expr", "dynamic_property_expr", "source_node_table", "destination_node_table")
    class Kind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        KIND_UNSPECIFIED: _ClassVar[GraphElementTableProto.Kind]
        NODE: _ClassVar[GraphElementTableProto.Kind]
        EDGE: _ClassVar[GraphElementTableProto.Kind]
    KIND_UNSPECIFIED: GraphElementTableProto.Kind
    NODE: GraphElementTableProto.Kind
    EDGE: GraphElementTableProto.Kind
    NAME_FIELD_NUMBER: _ClassVar[int]
    KIND_FIELD_NUMBER: _ClassVar[int]
    BASE_CATALOG_NAME_FIELD_NUMBER: _ClassVar[int]
    BASE_SCHEMA_NAME_FIELD_NUMBER: _ClassVar[int]
    BASE_TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    KEY_COLUMNS_FIELD_NUMBER: _ClassVar[int]
    LABEL_NAMES_FIELD_NUMBER: _ClassVar[int]
    PROPERTY_DEFINITIONS_FIELD_NUMBER: _ClassVar[int]
    DYNAMIC_LABEL_EXPR_FIELD_NUMBER: _ClassVar[int]
    DYNAMIC_PROPERTY_EXPR_FIELD_NUMBER: _ClassVar[int]
    SOURCE_NODE_TABLE_FIELD_NUMBER: _ClassVar[int]
    DESTINATION_NODE_TABLE_FIELD_NUMBER: _ClassVar[int]
    name: str
    kind: GraphElementTableProto.Kind
    base_catalog_name: str
    base_schema_name: str
    base_table_name: str
    key_columns: _containers.RepeatedScalarFieldContainer[str]
    label_names: _containers.RepeatedScalarFieldContainer[str]
    property_definitions: _containers.RepeatedCompositeFieldContainer[GraphPropertyDefinitionProto]
    dynamic_label_expr: str
    dynamic_property_expr: str
    source_node_table: GraphNodeTableReferenceProto
    destination_node_table: GraphNodeTableReferenceProto
    def __init__(self, name: _Optional[str] = ..., kind: _Optional[_Union[GraphElementTableProto.Kind, str]] = ..., base_catalog_name: _Optional[str] = ..., base_schema_name: _Optional[str] = ..., base_table_name: _Optional[str] = ..., key_columns: _Optional[_Iterable[str]] = ..., label_names: _Optional[_Iterable[str]] = ..., property_definitions: _Optional[_Iterable[_Union[GraphPropertyDefinitionProto, _Mapping]]] = ..., dynamic_label_expr: _Optional[str] = ..., dynamic_property_expr: _Optional[str] = ..., source_node_table: _Optional[_Union[GraphNodeTableReferenceProto, _Mapping]] = ..., destination_node_table: _Optional[_Union[GraphNodeTableReferenceProto, _Mapping]] = ...) -> None: ...

class GraphNodeTableReferenceProto(_message.Message):
    __slots__ = ("node_table_name", "edge_table_columns", "node_table_columns")
    NODE_TABLE_NAME_FIELD_NUMBER: _ClassVar[int]
    EDGE_TABLE_COLUMNS_FIELD_NUMBER: _ClassVar[int]
    NODE_TABLE_COLUMNS_FIELD_NUMBER: _ClassVar[int]
    node_table_name: str
    edge_table_columns: _containers.RepeatedScalarFieldContainer[str]
    node_table_columns: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, node_table_name: _Optional[str] = ..., edge_table_columns: _Optional[_Iterable[str]] = ..., node_table_columns: _Optional[_Iterable[str]] = ...) -> None: ...

class GraphElementLabelProto(_message.Message):
    __slots__ = ("name", "property_declaration_names")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PROPERTY_DECLARATION_NAMES_FIELD_NUMBER: _ClassVar[int]
    name: str
    property_declaration_names: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, name: _Optional[str] = ..., property_declaration_names: _Optional[_Iterable[str]] = ...) -> None: ...

class GraphPropertyDeclarationProto(_message.Message):
    __slots__ = ("name", "type")
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: str
    def __init__(self, name: _Optional[str] = ..., type: _Optional[str] = ...) -> None: ...

class GraphPropertyDefinitionProto(_message.Message):
    __slots__ = ("property_declaration_name", "value_expression_sql")
    PROPERTY_DECLARATION_NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_EXPRESSION_SQL_FIELD_NUMBER: _ClassVar[int]
    property_declaration_name: str
    value_expression_sql: str
    def __init__(self, property_declaration_name: _Optional[str] = ..., value_expression_sql: _Optional[str] = ...) -> None: ...



from google.protobuf import any_pb2 as _any_pb2
from zetasql.wasi._pb2.zetasql.proto import function_pb2 as _function_pb2
from zetasql.wasi._pb2.zetasql.proto import script_exception_pb2 as _script_exception_pb2
from zetasql.wasi._pb2.zetasql.scripting import procedure_extension_pb2 as _procedure_extension_pb2
from zetasql.wasi._pb2.zetasql.scripting import variable_pb2 as _variable_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ScriptExecutorStateProto(_message.Message):
    __slots__ = ("callstack", "pending_exceptions", "triggered_features", "timezone", "case_stmt_true_branch_index", "case_stmt_current_branch_index", "sql_feature_usage")
    class ScriptFeature(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        INVALID: _ClassVar[ScriptExecutorStateProto.ScriptFeature]
        EXCEPTION_CAUGHT: _ClassVar[ScriptExecutorStateProto.ScriptFeature]
        CALL_STATEMENT: _ClassVar[ScriptExecutorStateProto.ScriptFeature]
        EXECUTE_IMMEDIATE_STATEMENT: _ClassVar[ScriptExecutorStateProto.ScriptFeature]
    INVALID: ScriptExecutorStateProto.ScriptFeature
    EXCEPTION_CAUGHT: ScriptExecutorStateProto.ScriptFeature
    CALL_STATEMENT: ScriptExecutorStateProto.ScriptFeature
    EXECUTE_IMMEDIATE_STATEMENT: ScriptExecutorStateProto.ScriptFeature
    class ProcedureDefinition(_message.Message):
        __slots__ = ("name", "signature", "argument_name_list", "body", "is_dynamic_sql", "extension")
        NAME_FIELD_NUMBER: _ClassVar[int]
        SIGNATURE_FIELD_NUMBER: _ClassVar[int]
        ARGUMENT_NAME_LIST_FIELD_NUMBER: _ClassVar[int]
        BODY_FIELD_NUMBER: _ClassVar[int]
        IS_DYNAMIC_SQL_FIELD_NUMBER: _ClassVar[int]
        EXTENSION_FIELD_NUMBER: _ClassVar[int]
        name: str
        signature: _function_pb2.FunctionSignatureProto
        argument_name_list: _containers.RepeatedScalarFieldContainer[str]
        body: str
        is_dynamic_sql: bool
        extension: _procedure_extension_pb2.ProcedureExtension
        def __init__(self, name: _Optional[str] = ..., signature: _Optional[_Union[_function_pb2.FunctionSignatureProto, _Mapping]] = ..., argument_name_list: _Optional[_Iterable[str]] = ..., body: _Optional[str] = ..., is_dynamic_sql: bool = ..., extension: _Optional[_Union[_procedure_extension_pb2.ProcedureExtension, _Mapping]] = ...) -> None: ...
    class StackFrame(_message.Message):
        __slots__ = ("procedure_definition", "variables", "current_location_byte_offset", "control_flow_node_kind", "parameters", "for_loop_stack")
        class Parameters(_message.Message):
            __slots__ = ("mode", "variables")
            class ParameterMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
                __slots__ = ()
                NONE: _ClassVar[ScriptExecutorStateProto.StackFrame.Parameters.ParameterMode]
                NAMED: _ClassVar[ScriptExecutorStateProto.StackFrame.Parameters.ParameterMode]
                POSITIONAL: _ClassVar[ScriptExecutorStateProto.StackFrame.Parameters.ParameterMode]
            NONE: ScriptExecutorStateProto.StackFrame.Parameters.ParameterMode
            NAMED: ScriptExecutorStateProto.StackFrame.Parameters.ParameterMode
            POSITIONAL: ScriptExecutorStateProto.StackFrame.Parameters.ParameterMode
            MODE_FIELD_NUMBER: _ClassVar[int]
            VARIABLES_FIELD_NUMBER: _ClassVar[int]
            mode: ScriptExecutorStateProto.StackFrame.Parameters.ParameterMode
            variables: _containers.RepeatedCompositeFieldContainer[_variable_pb2.Variable]
            def __init__(self, mode: _Optional[_Union[ScriptExecutorStateProto.StackFrame.Parameters.ParameterMode, str]] = ..., variables: _Optional[_Iterable[_Union[_variable_pb2.Variable, _Mapping]]] = ...) -> None: ...
        PROCEDURE_DEFINITION_FIELD_NUMBER: _ClassVar[int]
        VARIABLES_FIELD_NUMBER: _ClassVar[int]
        CURRENT_LOCATION_BYTE_OFFSET_FIELD_NUMBER: _ClassVar[int]
        CONTROL_FLOW_NODE_KIND_FIELD_NUMBER: _ClassVar[int]
        PARAMETERS_FIELD_NUMBER: _ClassVar[int]
        FOR_LOOP_STACK_FIELD_NUMBER: _ClassVar[int]
        procedure_definition: ScriptExecutorStateProto.ProcedureDefinition
        variables: _containers.RepeatedCompositeFieldContainer[_variable_pb2.Variable]
        current_location_byte_offset: int
        control_flow_node_kind: int
        parameters: ScriptExecutorStateProto.StackFrame.Parameters
        for_loop_stack: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
        def __init__(self, procedure_definition: _Optional[_Union[ScriptExecutorStateProto.ProcedureDefinition, _Mapping]] = ..., variables: _Optional[_Iterable[_Union[_variable_pb2.Variable, _Mapping]]] = ..., current_location_byte_offset: _Optional[int] = ..., control_flow_node_kind: _Optional[int] = ..., parameters: _Optional[_Union[ScriptExecutorStateProto.StackFrame.Parameters, _Mapping]] = ..., for_loop_stack: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ...) -> None: ...
    class ScriptFeatureUsage(_message.Message):
        __slots__ = ("exception", "call_stmt", "execute_immediate_stmt")
        EXCEPTION_FIELD_NUMBER: _ClassVar[int]
        CALL_STMT_FIELD_NUMBER: _ClassVar[int]
        EXECUTE_IMMEDIATE_STMT_FIELD_NUMBER: _ClassVar[int]
        exception: int
        call_stmt: int
        execute_immediate_stmt: int
        def __init__(self, exception: _Optional[int] = ..., call_stmt: _Optional[int] = ..., execute_immediate_stmt: _Optional[int] = ...) -> None: ...
    CALLSTACK_FIELD_NUMBER: _ClassVar[int]
    PENDING_EXCEPTIONS_FIELD_NUMBER: _ClassVar[int]
    TRIGGERED_FEATURES_FIELD_NUMBER: _ClassVar[int]
    TIMEZONE_FIELD_NUMBER: _ClassVar[int]
    CASE_STMT_TRUE_BRANCH_INDEX_FIELD_NUMBER: _ClassVar[int]
    CASE_STMT_CURRENT_BRANCH_INDEX_FIELD_NUMBER: _ClassVar[int]
    SQL_FEATURE_USAGE_FIELD_NUMBER: _ClassVar[int]
    callstack: _containers.RepeatedCompositeFieldContainer[ScriptExecutorStateProto.StackFrame]
    pending_exceptions: _containers.RepeatedCompositeFieldContainer[_script_exception_pb2.ScriptException]
    triggered_features: _containers.RepeatedScalarFieldContainer[ScriptExecutorStateProto.ScriptFeature]
    timezone: str
    case_stmt_true_branch_index: int
    case_stmt_current_branch_index: int
    sql_feature_usage: ScriptExecutorStateProto.ScriptFeatureUsage
    def __init__(self, callstack: _Optional[_Iterable[_Union[ScriptExecutorStateProto.StackFrame, _Mapping]]] = ..., pending_exceptions: _Optional[_Iterable[_Union[_script_exception_pb2.ScriptException, _Mapping]]] = ..., triggered_features: _Optional[_Iterable[_Union[ScriptExecutorStateProto.ScriptFeature, str]]] = ..., timezone: _Optional[str] = ..., case_stmt_true_branch_index: _Optional[int] = ..., case_stmt_current_branch_index: _Optional[int] = ..., sql_feature_usage: _Optional[_Union[ScriptExecutorStateProto.ScriptFeatureUsage, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CollationProto(_message.Message):
    __slots__ = ("collation_name", "child_list")
    COLLATION_NAME_FIELD_NUMBER: _ClassVar[int]
    CHILD_LIST_FIELD_NUMBER: _ClassVar[int]
    collation_name: str
    child_list: _containers.RepeatedCompositeFieldContainer[CollationProto]
    def __init__(self, collation_name: _Optional[str] = ..., child_list: _Optional[_Iterable[_Union[CollationProto, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/simple_catalog.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/simple_catalog.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.proto import function_pb2 as zetasql_dot_proto_dot_function__pb2
from zetasql.wasi._pb2.zetasql.proto import options_pb2 as zetasql_dot_proto_dot_options__pb2
from zetasql.wasi._pb2.zetasql.proto import simple_property_graph_pb2 as zetasql_dot_proto_dot_simple__property__graph__pb2
from zetasql.wasi._pb2.zetasql.public import simple_connection_pb2 as zetasql_dot_public_dot_simple__connection__pb2
from zetasql.wasi._pb2.zetasql.public import simple_constant_pb2 as zetasql_dot_public_dot_simple__constant__pb2
from zetasql.wasi._pb2.zetasql.public import simple_model_pb2 as zetasql_dot_public_dot_simple__model__pb2
from zetasql.wasi._pb2.zetasql.public import simple_sequence_pb2 as zetasql_dot_public_dot_simple__sequence__pb2
from zetasql.wasi._pb2.zetasql.public import simple_table_pb2 as zetasql_dot_public_dot_simple__table__pb2
from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"zetasql/proto/simple_catalog.proto\x12\x07zetasql\x1a\x1czetasql/proto/function.proto\x1a\x1bzetasql/proto/options.proto\x1a)zetasql/proto/simple_property_graph.proto\x1a&zetasql/public/simple_connection.proto\x1a$zetasql/public/simple_constant.proto\x1a!zetasql/public/simple_model.proto\x1a$zetasql/public/simple_sequence.proto\x1a!zetasql/public/simple_table.proto\x1a\x19zetasql/public/type.proto\"\xff\x05\n\x12SimpleCatalogProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12(\n\x05table\x18\x02 \x03(\x0b\x32\x19.zetasql.SimpleTableProto\x12>\n\nnamed_type\x18\x03 \x03(\x0b\x32*.zetasql.SimpleCatalogProto.NamedTypeProto\x12,\n\x07\x63\x61talog\x18\x04 \x03(\x0b\x32\x1b.zetasql.SimpleCatalogProto\x12M\n\x18\x62uiltin_function_options\x18\x05 \x01(\x0b\x32+.zetasql.ZetaSQLBuiltinFunctionOptionsProto\x12/\n\x0f\x63ustom_function\x18\x06 \x03(\x0b\x32\x16.zetasql.FunctionProto\x12\x35\n\ncustom_tvf\x18\t \x03(\x0b\x32!.zetasql.TableValuedFunctionProto\x12%\n\x19\x66ile_descriptor_set_index\x18\x07 \x01(\x05:\x02-1\x12*\n\tprocedure\x18\x08 \x03(\x0b\x32\x17.zetasql.ProcedureProto\x12.\n\x08\x63onstant\x18\n \x03(\x0b\x32\x1c.zetasql.SimpleConstantProto\x12\x39\n\x0eproperty_graph\x18\x0b \x03(\x0b\x32!.zetasql.SimplePropertyGraphProto\x12\x32\n\nconnection\x18\x0c \x03(\x0b\x32\x1e.zetasql.SimpleConnectionProto\x12(\n\x05model\x18\r \x03(\x0b\x32\x19.zetasql.SimpleModelProto\x12.\n\x08sequence\x18\x0e \x03(\x0b\x32\x1c.zetasql.SimpleSequenceProto\x1a@\n\x0eNamedTypeProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x04type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProtoB)\n\x12\x63om.google.zetasqlB\x13SimpleCatalogProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.simple_catalog_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\023SimpleCatalogProtos'
  _globals['_SIMPLECATALOGPROTO']._serialized_start=363
  _globals['_SIMPLECATALOGPROTO']._serialized_end=1130
  _globals['_SIMPLECATALOGPROTO_NAMEDTYPEPROTO']._serialized_start=1066
  _globals['_SIMPLECATALOGPROTO_NAMEDTYPEPROTO']._serialized_end=1130
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/reference_impl/evaluator_table_iterator.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/reference_impl/evaluator_table_iterator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5zetasql/reference_impl/evaluator_table_iterator.proto\x12\x07zetasql\"S\n\x1b\x45valuatorTableIteratorProto\x12\x1c\n\x14location_byte_offset\x18\x01 \x01(\x05\x12\x16\n\x0enext_row_count\x18\x02 \x01(\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.reference_impl.evaluator_table_iterator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EVALUATORTABLEITERATORPROTO']._serialized_start=66
  _globals['_EVALUATORTABLEITERATORPROTO']._serialized_end=149
# @@protoc_insertion_point(module_scope)



"""ZetaSQL API Layer - Convenience Features.

This package provides Layer 2 convenience features:

- analyzer: High-level Analyzer class with static/instance methods
- parser: High-level Parser class for syntax-only parsing
- prepared_query: PreparedQuery with builder pattern and context management
- prepared_expression: PreparedExpression for evaluating expressions
- builders: Fluent builder APIs (CatalogBuilder, TableBuilder)

These features mirror the Java ZetaSQL API for familiarity.
"""

from .analyzer import Analyzer, ScriptMetadata, StatementType, ValidationResult, get_statement_type
from .ast_visitor import ASTNodeVisitor
from .builders import (
    CatalogBuilder,
    ConstantBuilder,
    FunctionBuilder,
    SignatureBuilder,
    TableBuilder,
    TVFBuilder,
)
from .parser import Parser
from .prepared_expression import PreparedExpression
from .prepared_query import PreparedQuery, PreparedQueryBuilder
from .resolved_visitor import ResolvedNodeVisitor
from .table_content import create_table_content
from .tree_visitor import TreeVisitor
from .type_factory import TypeFactory
from .value import Value

__all__ = [
    "ASTNodeVisitor",
    "Analyzer",
    "CatalogBuilder",
    "ConstantBuilder",
    "FunctionBuilder",
    "Parser",
    "PreparedExpression",
    "PreparedQuery",
    "PreparedQueryBuilder",
    "ResolvedNodeVisitor",
    "ScriptMetadata",
    "SignatureBuilder",
    "StatementType",
    "TVFBuilder",
    "TableBuilder",
    "TreeVisitor",
    "TypeFactory",
    "ValidationResult",
    "Value",
    "create_table_content",
    "get_statement_type",
]



from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PlaceholderDescriptorProto(_message.Message):
    __slots__ = ("is_placeholder",)
    PLACEHOLDER_DESCRIPTOR_FIELD_NUMBER: _ClassVar[int]
    placeholder_descriptor: _descriptor.FieldDescriptor
    IS_PLACEHOLDER_FIELD_NUMBER: _ClassVar[int]
    is_placeholder: bool
    def __init__(self, is_placeholder: bool = ...) -> None: ...



"""Internal helper utilities for builders."""

from zetasql.api.type_factory import TypeFactory
from zetasql.types import Type, TypeKind


def convert_to_type(type_or_kind: Type | TypeKind | int) -> Type:
    """Convert TypeKind to Type if needed.

    Args:
        type_or_kind: Type object or TypeKind enum value

    Returns:
        Type object
    """
    if isinstance(type_or_kind, (TypeKind, int)):
        return TypeFactory.create_simple_type(type_or_kind)
    return type_or_kind



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/resolved_ast/resolved_node_kind.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/resolved_ast/resolved_node_kind.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-zetasql/resolved_ast/resolved_node_kind.proto\x12\x07zetasql*\xc9J\n\x10ResolvedNodeKind\x12\x14\n\x10RESOLVED_LITERAL\x10\x03\x12\x16\n\x12RESOLVED_PARAMETER\x10\x04\x12\x1e\n\x1aRESOLVED_EXPRESSION_COLUMN\x10\x05\x12 \n\x1bRESOLVED_CATALOG_COLUMN_REF\x10\xce\x01\x12\x17\n\x13RESOLVED_COLUMN_REF\x10\x06\x12\'\n\"RESOLVED_GROUPING_SET_MULTI_COLUMN\x10\xed\x01\x12\x15\n\x11RESOLVED_CONSTANT\x10g\x12\x1d\n\x18RESOLVED_SYSTEM_VARIABLE\x10\x8b\x01\x12\x1b\n\x16RESOLVED_INLINE_LAMBDA\x10\x9f\x01\x12\x16\n\x11RESOLVED_SEQUENCE\x10\xe9\x01\x12\x1e\n\x19RESOLVED_FILTER_FIELD_ARG\x10\xad\x01\x12\x1a\n\x15RESOLVED_FILTER_FIELD\x10\xae\x01\x12\x1a\n\x16RESOLVED_FUNCTION_CALL\x10\x08\x12$\n RESOLVED_AGGREGATE_FUNCTION_CALL\x10\t\x12#\n\x1fRESOLVED_ANALYTIC_FUNCTION_CALL\x10\n\x12#\n\x1eRESOLVED_EXTENDED_CAST_ELEMENT\x10\x97\x01\x12\x1b\n\x16RESOLVED_EXTENDED_CAST\x10\x9e\x01\x12\x11\n\rRESOLVED_CAST\x10\x0b\x12\x18\n\x14RESOLVED_MAKE_STRUCT\x10\x0c\x12\x17\n\x13RESOLVED_MAKE_PROTO\x10\r\x12\x1d\n\x19RESOLVED_MAKE_PROTO_FIELD\x10\x0e\x12\x1d\n\x19RESOLVED_GET_STRUCT_FIELD\x10\x0f\x12\x1c\n\x18RESOLVED_GET_PROTO_FIELD\x10\x10\x12\x1c\n\x17RESOLVED_GET_JSON_FIELD\x10\xa5\x01\x12\x1b\n\x16RESOLVED_GET_ROW_FIELD\x10\xba\x02\x12\x15\n\x10RESOLVED_FLATTEN\x10\x95\x01\x12\x1b\n\x16RESOLVED_FLATTENED_ARG\x10\x96\x01\x12 \n\x1bRESOLVED_REPLACE_FIELD_ITEM\x10\x80\x01\x12\x1b\n\x16RESOLVED_REPLACE_FIELD\x10\x81\x01\x12\x1d\n\x18RESOLVED_GET_PROTO_ONEOF\x10\x82\x01\x12\x1a\n\x16RESOLVED_SUBQUERY_EXPR\x10\x11\x12\x17\n\x12RESOLVED_WITH_EXPR\x10\xc5\x01\x12\"\n\x1dRESOLVED_EXECUTE_AS_ROLE_SCAN\x10\xcf\x01\x12\x12\n\x0eRESOLVED_MODEL\x10m\x12\x18\n\x13RESOLVED_CONNECTION\x10\x8d\x01\x12\x18\n\x13RESOLVED_DESCRIPTOR\x10\x90\x01\x12\x1c\n\x18RESOLVED_SINGLE_ROW_SCAN\x10\x13\x12!\n\x1cRESOLVED_UNSET_ARGUMENT_SCAN\x10\xad\x02\x12\x17\n\x13RESOLVED_TABLE_SCAN\x10\x14\x12\x16\n\x12RESOLVED_JOIN_SCAN\x10\x15\x12\x17\n\x13RESOLVED_ARRAY_SCAN\x10\x16\x12\x1a\n\x16RESOLVED_COLUMN_HOLDER\x10\x17\x12\x18\n\x14RESOLVED_FILTER_SCAN\x10\x18\x12\x1b\n\x16RESOLVED_GROUPING_CALL\x10\xf1\x01\x12\x1f\n\x1aRESOLVED_GROUPING_SET_LIST\x10\xae\x02\x12\"\n\x1dRESOLVED_GROUPING_SET_PRODUCT\x10\xaf\x02\x12\x19\n\x15RESOLVED_GROUPING_SET\x10]\x12\x14\n\x0fRESOLVED_ROLLUP\x10\xef\x01\x12\x12\n\rRESOLVED_CUBE\x10\xf0\x01\x12\x1b\n\x17RESOLVED_AGGREGATE_SCAN\x10\x19\x12&\n\"RESOLVED_ANONYMIZED_AGGREGATE_SCAN\x10p\x12\x31\n,RESOLVED_DIFFERENTIAL_PRIVACY_AGGREGATE_SCAN\x10\xdd\x01\x12\x32\n-RESOLVED_AGGREGATION_THRESHOLD_AGGREGATE_SCAN\x10\xe4\x01\x12\x1f\n\x1bRESOLVED_SET_OPERATION_ITEM\x10^\x12\x1f\n\x1bRESOLVED_SET_OPERATION_SCAN\x10\x1a\x12\x1a\n\x16RESOLVED_ORDER_BY_SCAN\x10\x1b\x12\x1e\n\x1aRESOLVED_LIMIT_OFFSET_SCAN\x10\x1c\x12\x1a\n\x16RESOLVED_WITH_REF_SCAN\x10\x1d\x12\x1a\n\x16RESOLVED_ANALYTIC_SCAN\x10\x1e\x12\x18\n\x14RESOLVED_SAMPLE_SCAN\x10\x1f\x12\x1c\n\x18RESOLVED_COMPUTED_COLUMN\x10 \x12&\n!RESOLVED_DEFERRED_COMPUTED_COLUMN\x10\xff\x01\x12\x1a\n\x16RESOLVED_ORDER_BY_ITEM\x10!\x12\x1f\n\x1bRESOLVED_COLUMN_ANNOTATIONS\x10h\x12\"\n\x1eRESOLVED_GENERATED_COLUMN_INFO\x10i\x12\"\n\x1dRESOLVED_COLUMN_DEFAULT_VALUE\x10\xbc\x01\x12\x1e\n\x1aRESOLVED_COLUMN_DEFINITION\x10[\x12\x18\n\x14RESOLVED_PRIMARY_KEY\x10\\\x12\x18\n\x14RESOLVED_FOREIGN_KEY\x10n\x12\x1d\n\x19RESOLVED_CHECK_CONSTRAINT\x10q\x12\x1a\n\x16RESOLVED_OUTPUT_COLUMN\x10\"\x12\x1b\n\x16RESOLVED_OUTPUT_SCHEMA\x10\x97\x02\x12\x19\n\x15RESOLVED_PROJECT_SCAN\x10#\x12\x14\n\x10RESOLVED_TVFSCAN\x10Q\x12\x1d\n\x18RESOLVED_GROUP_ROWS_SCAN\x10\xb0\x01\x12\x1e\n\x1aRESOLVED_FUNCTION_ARGUMENT\x10R\x12\x19\n\x15RESOLVED_EXPLAIN_STMT\x10%\x12\x30\n+RESOLVED_STATEMENT_WITH_PIPE_OPERATORS_STMT\x10\xb6\x02\x12\x17\n\x13RESOLVED_QUERY_STMT\x10&\x12$\n\x1fRESOLVED_GENERALIZED_QUERY_STMT\x10\x9a\x02\x12\x18\n\x13RESOLVED_MULTI_STMT\x10\x9f\x02\x12$\n\x1fRESOLVED_CREATE_WITH_ENTRY_STMT\x10\xa0\x02\x12!\n\x1dRESOLVED_CREATE_DATABASE_STMT\x10_\x12\x17\n\x13RESOLVED_INDEX_ITEM\x10`\x12\x18\n\x14RESOLVED_UNNEST_ITEM\x10~\x12\x1e\n\x1aRESOLVED_CREATE_INDEX_STMT\x10\x61\x12 \n\x1bRESOLVED_CREATE_SCHEMA_STMT\x10\x9d\x01\x12)\n$RESOLVED_CREATE_EXTERNAL_SCHEMA_STMT\x10\xf9\x01\x12\x1e\n\x1aRESOLVED_CREATE_TABLE_STMT\x10Z\x12(\n$RESOLVED_CREATE_TABLE_AS_SELECT_STMT\x10(\x12(\n#RESOLVED_CREATE_MODEL_ALIASED_QUERY\x10\xe2\x01\x12\x1e\n\x1aRESOLVED_CREATE_MODEL_STMT\x10k\x12\x1d\n\x19RESOLVED_CREATE_VIEW_STMT\x10)\x12$\n\x1fRESOLVED_WITH_PARTITION_COLUMNS\x10\x99\x01\x12(\n#RESOLVED_CREATE_SNAPSHOT_TABLE_STMT\x10\xb6\x01\x12\'\n#RESOLVED_CREATE_EXTERNAL_TABLE_STMT\x10*\x12\x1f\n\x1aRESOLVED_EXPORT_MODEL_STMT\x10\x98\x01\x12\x1d\n\x19RESOLVED_EXPORT_DATA_STMT\x10+\x12\"\n\x1dRESOLVED_EXPORT_METADATA_STMT\x10\xea\x01\x12\x1e\n\x1aRESOLVED_DEFINE_TABLE_STMT\x10,\x12\x1a\n\x16RESOLVED_DESCRIBE_STMT\x10-\x12\x16\n\x12RESOLVED_SHOW_STMT\x10.\x12\x17\n\x13RESOLVED_BEGIN_STMT\x10/\x12!\n\x1dRESOLVED_SET_TRANSACTION_STMT\x10x\x12\x18\n\x14RESOLVED_COMMIT_STMT\x10\x30\x12\x1a\n\x16RESOLVED_ROLLBACK_STMT\x10\x31\x12\x1d\n\x19RESOLVED_START_BATCH_STMT\x10z\x12\x1b\n\x17RESOLVED_RUN_BATCH_STMT\x10{\x12\x1d\n\x19RESOLVED_ABORT_BATCH_STMT\x10|\x12\x16\n\x12RESOLVED_DROP_STMT\x10\x32\x12(\n$RESOLVED_DROP_MATERIALIZED_VIEW_STMT\x10y\x12&\n!RESOLVED_DROP_SNAPSHOT_TABLE_STMT\x10\xb7\x01\x12 \n\x1bRESOLVED_RECURSIVE_REF_SCAN\x10\x93\x01\x12&\n!RESOLVED_RECURSION_DEPTH_MODIFIER\x10\x80\x02\x12\x1c\n\x17RESOLVED_RECURSIVE_SCAN\x10\x94\x01\x12\x16\n\x12RESOLVED_WITH_SCAN\x10\x33\x12\x17\n\x13RESOLVED_WITH_ENTRY\x10\x34\x12\x13\n\x0fRESOLVED_OPTION\x10\x35\x12 \n\x1cRESOLVED_WINDOW_PARTITIONING\x10\x36\x12\x1c\n\x18RESOLVED_WINDOW_ORDERING\x10\x37\x12\x19\n\x15RESOLVED_WINDOW_FRAME\x10\x38\x12$\n RESOLVED_ANALYTIC_FUNCTION_GROUP\x10\x39\x12\x1e\n\x1aRESOLVED_WINDOW_FRAME_EXPR\x10:\x12\x15\n\x11RESOLVED_DMLVALUE\x10;\x12\x17\n\x13RESOLVED_DMLDEFAULT\x10<\x12\x18\n\x14RESOLVED_ASSERT_STMT\x10\x62\x12!\n\x1dRESOLVED_ASSERT_ROWS_MODIFIED\x10=\x12 \n\x1bRESOLVED_ON_CONFLICT_CLAUSE\x10\x99\x02\x12\x17\n\x13RESOLVED_INSERT_ROW\x10>\x12\x18\n\x14RESOLVED_INSERT_STMT\x10?\x12\x18\n\x14RESOLVED_DELETE_STMT\x10@\x12\x18\n\x14RESOLVED_UPDATE_ITEM\x10\x41\x12 \n\x1cRESOLVED_UPDATE_ITEM_ELEMENT\x10\x66\x12\x18\n\x14RESOLVED_UPDATE_STMT\x10\x42\x12\x17\n\x13RESOLVED_MERGE_WHEN\x10\x64\x12\x17\n\x13RESOLVED_MERGE_STMT\x10\x65\x12\x1b\n\x16RESOLVED_TRUNCATE_STMT\x10\x85\x01\x12\x19\n\x14RESOLVED_OBJECT_UNIT\x10\xc8\x01\x12\x16\n\x12RESOLVED_PRIVILEGE\x10\x43\x12\x17\n\x13RESOLVED_GRANT_STMT\x10\x45\x12\x18\n\x14RESOLVED_REVOKE_STMT\x10\x46\x12!\n\x1cRESOLVED_ALTER_DATABASE_STMT\x10\x86\x01\x12\x1e\n\x19RESOLVED_ALTER_INDEX_STMT\x10\xa4\x02\x12)\n%RESOLVED_ALTER_MATERIALIZED_VIEW_STMT\x10\x7f\x12$\n\x1fRESOLVED_ALTER_APPROX_VIEW_STMT\x10\xec\x01\x12\x1f\n\x1aRESOLVED_ALTER_SCHEMA_STMT\x10\xa0\x01\x12(\n#RESOLVED_ALTER_EXTERNAL_SCHEMA_STMT\x10\xfa\x01\x12\x1e\n\x19RESOLVED_ALTER_MODEL_STMT\x10\xcd\x01\x12\x1d\n\x19RESOLVED_ALTER_TABLE_STMT\x10s\x12\x1c\n\x18RESOLVED_ALTER_VIEW_STMT\x10v\x12\x1f\n\x1bRESOLVED_SET_OPTIONS_ACTION\x10u\x12%\n RESOLVED_ALTER_SUB_ENTITY_ACTION\x10\xca\x01\x12#\n\x1eRESOLVED_ADD_SUB_ENTITY_ACTION\x10\xcb\x01\x12$\n\x1fRESOLVED_DROP_SUB_ENTITY_ACTION\x10\xcc\x01\x12\x1f\n\x1aRESOLVED_ADD_COLUMN_ACTION\x10\x83\x01\x12*\n%RESOLVED_ADD_COLUMN_IDENTIFIER_ACTION\x10\xa5\x02\x12\x1c\n\x17RESOLVED_REBUILD_ACTION\x10\xa6\x02\x12#\n\x1eRESOLVED_ADD_CONSTRAINT_ACTION\x10\xa3\x01\x12$\n\x1fRESOLVED_DROP_CONSTRAINT_ACTION\x10\xa4\x01\x12%\n RESOLVED_DROP_PRIMARY_KEY_ACTION\x10\xb8\x01\x12)\n$RESOLVED_ALTER_COLUMN_OPTIONS_ACTION\x10\xa9\x01\x12/\n*RESOLVED_ALTER_COLUMN_DROP_NOT_NULL_ACTION\x10\xb2\x01\x12\x30\n+RESOLVED_ALTER_COLUMN_DROP_GENERATED_ACTION\x10\xf3\x01\x12/\n*RESOLVED_ALTER_COLUMN_SET_GENERATED_ACTION\x10\xb0\x02\x12/\n*RESOLVED_ALTER_COLUMN_SET_DATA_TYPE_ACTION\x10\xb5\x01\x12-\n(RESOLVED_ALTER_COLUMN_SET_DEFAULT_ACTION\x10\xc6\x01\x12.\n)RESOLVED_ALTER_COLUMN_DROP_DEFAULT_ACTION\x10\xc7\x01\x12 \n\x1bRESOLVED_DROP_COLUMN_ACTION\x10\x84\x01\x12\"\n\x1dRESOLVED_RENAME_COLUMN_ACTION\x10\xb9\x01\x12\x1b\n\x16RESOLVED_SET_AS_ACTION\x10\x9c\x01\x12 \n\x1bRESOLVED_SET_COLLATE_CLAUSE\x10\xbb\x01\x12)\n%RESOLVED_ALTER_TABLE_SET_OPTIONS_STMT\x10G\x12\x18\n\x14RESOLVED_RENAME_STMT\x10H\x12/\n*RESOLVED_CREATE_PRIVILEGE_RESTRICTION_STMT\x10\xbf\x01\x12*\n&RESOLVED_CREATE_ROW_ACCESS_POLICY_STMT\x10I\x12-\n(RESOLVED_DROP_PRIVILEGE_RESTRICTION_STMT\x10\xc0\x01\x12(\n$RESOLVED_DROP_ROW_ACCESS_POLICY_STMT\x10J\x12\x1d\n\x18RESOLVED_DROP_INDEX_STMT\x10\xf2\x01\x12\x1d\n\x18RESOLVED_GRANT_TO_ACTION\x10\x87\x01\x12 \n\x1bRESOLVED_RESTRICT_TO_ACTION\x10\xc1\x01\x12+\n&RESOLVED_ADD_TO_RESTRICTEE_LIST_ACTION\x10\xc2\x01\x12\x30\n+RESOLVED_REMOVE_FROM_RESTRICTEE_LIST_ACTION\x10\xc3\x01\x12!\n\x1cRESOLVED_FILTER_USING_ACTION\x10\x88\x01\x12 \n\x1bRESOLVED_REVOKE_FROM_ACTION\x10\x89\x01\x12\x1e\n\x19RESOLVED_RENAME_TO_ACTION\x10\x8a\x01\x12.\n)RESOLVED_ALTER_PRIVILEGE_RESTRICTION_STMT\x10\xc4\x01\x12)\n%RESOLVED_ALTER_ROW_ACCESS_POLICY_STMT\x10K\x12\x30\n+RESOLVED_ALTER_ALL_ROW_ACCESS_POLICIES_STMT\x10\x91\x01\x12!\n\x1dRESOLVED_CREATE_CONSTANT_STMT\x10\x63\x12!\n\x1dRESOLVED_CREATE_FUNCTION_STMT\x10L\x12\x19\n\x15RESOLVED_ARGUMENT_DEF\x10M\x12\x19\n\x15RESOLVED_ARGUMENT_REF\x10N\x12\'\n#RESOLVED_CREATE_TABLE_FUNCTION_STMT\x10X\x12#\n\x1fRESOLVED_RELATION_ARGUMENT_SCAN\x10Y\x12\x1a\n\x16RESOLVED_ARGUMENT_LIST\x10O\x12&\n\"RESOLVED_FUNCTION_SIGNATURE_HOLDER\x10T\x12\x1f\n\x1bRESOLVED_DROP_FUNCTION_STMT\x10P\x12&\n!RESOLVED_DROP_TABLE_FUNCTION_STMT\x10\xaf\x01\x12\x16\n\x12RESOLVED_CALL_STMT\x10S\x12\x18\n\x14RESOLVED_IMPORT_STMT\x10V\x12\x18\n\x14RESOLVED_MODULE_STMT\x10W\x12&\n\"RESOLVED_AGGREGATE_HAVING_MODIFIER\x10U\x12*\n&RESOLVED_CREATE_MATERIALIZED_VIEW_STMT\x10w\x12%\n RESOLVED_CREATE_APPROX_VIEW_STMT\x10\xeb\x01\x12\"\n\x1eRESOLVED_CREATE_PROCEDURE_STMT\x10}\x12(\n#RESOLVED_EXECUTE_IMMEDIATE_ARGUMENT\x10\x8f\x01\x12$\n\x1fRESOLVED_EXECUTE_IMMEDIATE_STMT\x10\x8c\x01\x12\x1d\n\x18RESOLVED_ASSIGNMENT_STMT\x10\x8e\x01\x12 \n\x1bRESOLVED_CREATE_ENTITY_STMT\x10\x9a\x01\x12\x1f\n\x1aRESOLVED_ALTER_ENTITY_STMT\x10\x9b\x01\x12\x1a\n\x15RESOLVED_PIVOT_COLUMN\x10\xa6\x01\x12\x18\n\x13RESOLVED_PIVOT_SCAN\x10\xa1\x01\x12\x1e\n\x19RESOLVED_RETURNING_CLAUSE\x10\xaa\x01\x12\x19\n\x14RESOLVED_UNPIVOT_ARG\x10\xab\x01\x12\x1a\n\x15RESOLVED_UNPIVOT_SCAN\x10\xac\x01\x12\"\n\x1dRESOLVED_MATCH_RECOGNIZE_SCAN\x10\x89\x02\x12\x1b\n\x16RESOLVED_MEASURE_GROUP\x10\x98\x02\x12\x31\n,RESOLVED_MATCH_RECOGNIZE_VARIABLE_DEFINITION\x10\x8a\x02\x12+\n&RESOLVED_MATCH_RECOGNIZE_PATTERN_EMPTY\x10\x8c\x02\x12,\n\'RESOLVED_MATCH_RECOGNIZE_PATTERN_ANCHOR\x10\x94\x02\x12\x32\n-RESOLVED_MATCH_RECOGNIZE_PATTERN_VARIABLE_REF\x10\x8d\x02\x12/\n*RESOLVED_MATCH_RECOGNIZE_PATTERN_OPERATION\x10\x8e\x02\x12\x34\n/RESOLVED_MATCH_RECOGNIZE_PATTERN_QUANTIFICATION\x10\x8f\x02\x12\x1d\n\x18RESOLVED_CLONE_DATA_STMT\x10\xb1\x01\x12#\n\x1eRESOLVED_TABLE_AND_COLUMN_INFO\x10\xb3\x01\x12\x1a\n\x15RESOLVED_ANALYZE_STMT\x10\xb4\x01\x12,\n\'RESOLVED_AUX_LOAD_DATA_PARTITION_FILTER\x10\xde\x01\x12 \n\x1bRESOLVED_AUX_LOAD_DATA_STMT\x10\xba\x01\x12(\n#RESOLVED_CREATE_PROPERTY_GRAPH_STMT\x10\xdf\x01\x12!\n\x1cRESOLVED_GRAPH_ELEMENT_TABLE\x10\xe0\x01\x12(\n#RESOLVED_GRAPH_NODE_TABLE_REFERENCE\x10\xe1\x01\x12!\n\x1cRESOLVED_GRAPH_ELEMENT_LABEL\x10\xe6\x01\x12(\n#RESOLVED_GRAPH_PROPERTY_DECLARATION\x10\xe7\x01\x12\'\n\"RESOLVED_GRAPH_PROPERTY_DEFINITION\x10\xe8\x01\x12/\n*RESOLVED_GRAPH_DYNAMIC_LABEL_SPECIFICATION\x10\xa2\x02\x12\x34\n/RESOLVED_GRAPH_DYNAMIC_PROPERTIES_SPECIFICATION\x10\xa3\x02\x12\x1c\n\x17RESOLVED_GRAPH_REF_SCAN\x10\xf6\x01\x12\x1f\n\x1aRESOLVED_GRAPH_LINEAR_SCAN\x10\xf7\x01\x12\x1e\n\x19RESOLVED_GRAPH_TABLE_SCAN\x10\xd0\x01\x12\x1d\n\x18RESOLVED_GRAPH_CALL_SCAN\x10\xab\x02\x12\x18\n\x13RESOLVED_GRAPH_SCAN\x10\xe5\x01\x12+\n&RESOLVED_GRAPH_PATH_PATTERN_QUANTIFIER\x10\xf5\x01\x12&\n!RESOLVED_GRAPH_PATH_SEARCH_PREFIX\x10\x84\x02\x12\x1d\n\x18RESOLVED_GRAPH_NODE_SCAN\x10\xd1\x01\x12\x1d\n\x18RESOLVED_GRAPH_EDGE_SCAN\x10\xd8\x01\x12(\n#RESOLVED_GRAPH_GET_ELEMENT_PROPERTY\x10\xd2\x01\x12#\n\x1eRESOLVED_GRAPH_LABEL_NARY_EXPR\x10\xd4\x01\x12\x19\n\x14RESOLVED_GRAPH_LABEL\x10\xd5\x01\x12#\n\x1eRESOLVED_GRAPH_WILD_CARD_LABEL\x10\xd6\x01\x12&\n!RESOLVED_GRAPH_ELEMENT_IDENTIFIER\x10\xd9\x01\x12$\n\x1fRESOLVED_GRAPH_ELEMENT_PROPERTY\x10\xda\x01\x12 \n\x1bRESOLVED_GRAPH_MAKE_ELEMENT\x10\xdb\x01\x12\x1d\n\x18RESOLVED_ARRAY_AGGREGATE\x10\x81\x02\x12\'\n\"RESOLVED_GRAPH_MAKE_ARRAY_VARIABLE\x10\x82\x02\x12\x1d\n\x18RESOLVED_GRAPH_PATH_MODE\x10\x83\x02\x12\x1d\n\x18RESOLVED_GRAPH_PATH_COST\x10\xaa\x02\x12\x1d\n\x18RESOLVED_GRAPH_PATH_SCAN\x10\xdc\x01\x12(\n#RESOLVED_GRAPH_IS_LABELED_PREDICATE\x10\x86\x02\x12\x19\n\x14RESOLVED_UNDROP_STMT\x10\xe3\x01\x12\"\n\x1dRESOLVED_IDENTITY_COLUMN_INFO\x10\xf4\x01\x12\x1b\n\x16RESOLVED_DESCRIBE_SCAN\x10\xac\x02\x12\"\n\x1dRESOLVED_STATIC_DESCRIBE_SCAN\x10\xfb\x01\x12\x19\n\x14RESOLVED_ASSERT_SCAN\x10\xfc\x01\x12\x16\n\x11RESOLVED_LOG_SCAN\x10\x90\x02\x12\x1a\n\x15RESOLVED_PIPE_IF_SCAN\x10\x95\x02\x12\x1a\n\x15RESOLVED_PIPE_IF_CASE\x10\x96\x02\x12\x1c\n\x17RESOLVED_PIPE_FORK_SCAN\x10\x9b\x02\x12\x1b\n\x16RESOLVED_PIPE_TEE_SCAN\x10\xa1\x02\x12#\n\x1eRESOLVED_PIPE_EXPORT_DATA_SCAN\x10\x9d\x02\x12$\n\x1fRESOLVED_PIPE_CREATE_TABLE_SCAN\x10\x9e\x02\x12\x1e\n\x19RESOLVED_PIPE_INSERT_SCAN\x10\xa9\x02\x12\x19\n\x14RESOLVED_SUBPIPELINE\x10\x91\x02\x12$\n\x1fRESOLVED_SUBPIPELINE_INPUT_SCAN\x10\x92\x02\x12\x1e\n\x19RESOLVED_SUBPIPELINE_STMT\x10\xb4\x02\x12+\n&RESOLVED_GENERALIZED_QUERY_SUBPIPELINE\x10\x9c\x02\x12\x1a\n\x15RESOLVED_BARRIER_SCAN\x10\x85\x02\x12$\n\x1fRESOLVED_CREATE_CONNECTION_STMT\x10\x87\x02\x12#\n\x1eRESOLVED_ALTER_CONNECTION_STMT\x10\x88\x02\x12\x17\n\x12RESOLVED_LOCK_MODE\x10\x93\x02\x12\x1f\n\x1aRESOLVED_UPDATE_FIELD_ITEM\x10\xa7\x02\x12 \n\x1bRESOLVED_UPDATE_CONSTRUCTOR\x10\xa8\x02\x12\"\n\x1dRESOLVED_CREATE_SEQUENCE_STMT\x10\xb2\x02\x12!\n\x1cRESOLVED_ALTER_SEQUENCE_STMT\x10\xb3\x02\x12;\n.__ResolvedNodeKind__switch_must_have_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x42-\n\x12\x63om.google.zetasqlB\x17ZetaSQLResolvedNodeKind')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.resolved_ast.resolved_node_kind_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\027ZetaSQLResolvedNodeKind'
  _globals['_RESOLVEDNODEKIND']._serialized_start=59
  _globals['_RESOLVEDNODEKIND']._serialized_end=9604
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FeatureLabelDictionaryProto(_message.Message):
    __slots__ = ("label_mapping", "encoded_labels")
    class LabelMappingEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: int
        value: str
        def __init__(self, key: _Optional[int] = ..., value: _Optional[str] = ...) -> None: ...
    class LabelSet(_message.Message):
        __slots__ = ("label",)
        LABEL_FIELD_NUMBER: _ClassVar[int]
        label: _containers.RepeatedScalarFieldContainer[int]
        def __init__(self, label: _Optional[_Iterable[int]] = ...) -> None: ...
    class EncodedLabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: int
        value: FeatureLabelDictionaryProto.LabelSet
        def __init__(self, key: _Optional[int] = ..., value: _Optional[_Union[FeatureLabelDictionaryProto.LabelSet, _Mapping]] = ...) -> None: ...
    LABEL_MAPPING_FIELD_NUMBER: _ClassVar[int]
    ENCODED_LABELS_FIELD_NUMBER: _ClassVar[int]
    label_mapping: _containers.ScalarMap[int, str]
    encoded_labels: _containers.MessageMap[int, FeatureLabelDictionaryProto.LabelSet]
    def __init__(self, label_mapping: _Optional[_Mapping[int, str]] = ..., encoded_labels: _Optional[_Mapping[int, FeatureLabelDictionaryProto.LabelSet]] = ...) -> None: ...



from zetasql.wasi._pb2.zetasql.public import collation_pb2 as _collation_pb2
from zetasql.wasi._pb2.zetasql.public import type_parameters_pb2 as _type_parameters_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TypeModifiersProto(_message.Message):
    __slots__ = ("type_parameters", "collation")
    TYPE_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    COLLATION_FIELD_NUMBER: _ClassVar[int]
    type_parameters: _type_parameters_pb2.TypeParametersProto
    collation: _collation_pb2.CollationProto
    def __init__(self, type_parameters: _Optional[_Union[_type_parameters_pb2.TypeParametersProto, _Mapping]] = ..., collation: _Optional[_Union[_collation_pb2.CollationProto, _Mapping]] = ...) -> None: ...



"""ZetaSQL Builders - Fluent Builder APIs.

Provides builder pattern implementations for constructing ZetaSQL objects:

- CatalogBuilder: Build SimpleCatalog with method chaining
- TableBuilder: Build SimpleTable with method chaining
- FunctionBuilder: Build Function with method chaining
- SignatureBuilder: Build FunctionSignature with method chaining
- TVFBuilder: Build TableValuedFunction with method chaining
- ConstantBuilder: Build SimpleConstant with method chaining
"""

from .catalog_builder import CatalogBuilder
from .constant_builder import ConstantBuilder
from .function_builder import FunctionBuilder, SignatureBuilder
from .table_builder import TableBuilder
from .tvf_builder import TVFBuilder

__all__ = [
    "CatalogBuilder",
    "ConstantBuilder",
    "FunctionBuilder",
    "SignatureBuilder",
    "TVFBuilder",
    "TableBuilder",
]



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class DateTimestampPart(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    __DateTimePart__switch_must_have_a_default__: _ClassVar[DateTimestampPart]
    YEAR: _ClassVar[DateTimestampPart]
    MONTH: _ClassVar[DateTimestampPart]
    DAY: _ClassVar[DateTimestampPart]
    DAYOFWEEK: _ClassVar[DateTimestampPart]
    DAYOFYEAR: _ClassVar[DateTimestampPart]
    QUARTER: _ClassVar[DateTimestampPart]
    HOUR: _ClassVar[DateTimestampPart]
    MINUTE: _ClassVar[DateTimestampPart]
    SECOND: _ClassVar[DateTimestampPart]
    MILLISECOND: _ClassVar[DateTimestampPart]
    MICROSECOND: _ClassVar[DateTimestampPart]
    NANOSECOND: _ClassVar[DateTimestampPart]
    PICOSECOND: _ClassVar[DateTimestampPart]
    DATE: _ClassVar[DateTimestampPart]
    WEEK: _ClassVar[DateTimestampPart]
    DATETIME: _ClassVar[DateTimestampPart]
    TIME: _ClassVar[DateTimestampPart]
    ISOYEAR: _ClassVar[DateTimestampPart]
    ISOWEEK: _ClassVar[DateTimestampPart]
    WEEK_MONDAY: _ClassVar[DateTimestampPart]
    WEEK_TUESDAY: _ClassVar[DateTimestampPart]
    WEEK_WEDNESDAY: _ClassVar[DateTimestampPart]
    WEEK_THURSDAY: _ClassVar[DateTimestampPart]
    WEEK_FRIDAY: _ClassVar[DateTimestampPart]
    WEEK_SATURDAY: _ClassVar[DateTimestampPart]
__DateTimePart__switch_must_have_a_default__: DateTimestampPart
YEAR: DateTimestampPart
MONTH: DateTimestampPart
DAY: DateTimestampPart
DAYOFWEEK: DateTimestampPart
DAYOFYEAR: DateTimestampPart
QUARTER: DateTimestampPart
HOUR: DateTimestampPart
MINUTE: DateTimestampPart
SECOND: DateTimestampPart
MILLISECOND: DateTimestampPart
MICROSECOND: DateTimestampPart
NANOSECOND: DateTimestampPart
PICOSECOND: DateTimestampPart
DATE: DateTimestampPart
WEEK: DateTimestampPart
DATETIME: DateTimestampPart
TIME: DateTimestampPart
ISOYEAR: DateTimestampPart
ISOWEEK: DateTimestampPart
WEEK_MONDAY: DateTimestampPart
WEEK_TUESDAY: DateTimestampPart
WEEK_WEDNESDAY: DateTimestampPart
WEEK_THURSDAY: DateTimestampPart
WEEK_FRIDAY: DateTimestampPart
WEEK_SATURDAY: DateTimestampPart



from collections.abc import Callable
from typing import TYPE_CHECKING, Concatenate, ParamSpec, TypeVar

P = ParamSpec("P")
R = TypeVar("R")


def parameters(param_func: Callable[P, R]):
    """Decorator for parameter type hints without runtime overhead.

    Uses param_func signature for type checking while preserving original function at runtime.
    """
    S2 = TypeVar("S2")
    P2 = ParamSpec("P2")
    R2 = TypeVar("R2")
    P3 = ParamSpec("P3")
    R3 = TypeVar("R3")

    def decorator(func: Callable[Concatenate[S2, P2], R2], _: Callable[P3, R3] = param_func):
        def wrapper(self: S2, *args: P3.args, **kwargs: P3.kwargs) -> R2:
            return func(self, *args, **kwargs)

        return wrapper if TYPE_CHECKING else func

    return decorator



from .generated import *  # noqa: F403,I001
from .proto_model import *  # noqa: F403
from .extensions import *  # noqa: F403

__all__ = [
    *proto_model.__all__,  # noqa: F405
    *generated.__all__,  # noqa: F405
    *extensions.__all__,  # noqa: F405
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/resolved_ast/resolved_ast_enums.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/resolved_ast/resolved_ast_enums.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-zetasql/resolved_ast/resolved_ast_enums.proto\x12\x07zetasql\"\x96\x01\n\x19ResolvedSubqueryExprEnums\"y\n\x0cSubqueryType\x12\n\n\x06SCALAR\x10\x00\x12\t\n\x05\x41RRAY\x10\x01\x12\n\n\x06\x45XISTS\x10\x02\x12\x06\n\x02IN\x10\x03\x12\x0c\n\x08LIKE_ANY\x10\x04\x12\x0c\n\x08LIKE_ALL\x10\x05\x12\x10\n\x0cNOT_LIKE_ANY\x10\x06\x12\x10\n\x0cNOT_LIKE_ALL\x10\x07\"M\n\x15ResolvedJoinScanEnums\"4\n\x08JoinType\x12\t\n\x05INNER\x10\x00\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02\x12\x08\n\x04\x46ULL\x10\x03\"\xd0\x02\n\x1dResolvedSetOperationScanEnums\"\x85\x01\n\x10SetOperationType\x12\r\n\tUNION_ALL\x10\x00\x12\x12\n\x0eUNION_DISTINCT\x10\x01\x12\x11\n\rINTERSECT_ALL\x10\x02\x12\x16\n\x12INTERSECT_DISTINCT\x10\x03\x12\x0e\n\nEXCEPT_ALL\x10\x04\x12\x13\n\x0f\x45XCEPT_DISTINCT\x10\x05\"W\n\x1bSetOperationColumnMatchMode\x12\x0f\n\x0b\x42Y_POSITION\x10\x00\x12\x11\n\rCORRESPONDING\x10\x01\x12\x14\n\x10\x43ORRESPONDING_BY\x10\x02\"N\n!SetOperationColumnPropagationMode\x12\n\n\x06STRICT\x10\x00\x12\t\n\x05INNER\x10\x01\x12\x08\n\x04LEFT\x10\x02\x12\x08\n\x04\x46ULL\x10\x03\"\\\n\x1aResolvedRecursiveScanEnums\">\n\x19RecursiveSetOperationType\x12\r\n\tUNION_ALL\x10\x00\x12\x12\n\x0eUNION_DISTINCT\x10\x01\">\n\x17ResolvedSampleScanEnums\"#\n\nSampleUnit\x12\x08\n\x04ROWS\x10\x00\x12\x0b\n\x07PERCENT\x10\x01\"c\n\x18ResolvedOrderByItemEnums\"G\n\rNullOrderMode\x12\x15\n\x11ORDER_UNSPECIFIED\x10\x00\x12\x0f\n\x0bNULLS_FIRST\x10\x01\x12\x0e\n\nNULLS_LAST\x10\x02\"\xf4\x03\n\x1cResolvedCreateStatementEnums\"_\n\x0b\x43reateScope\x12\x18\n\x14\x43REATE_DEFAULT_SCOPE\x10\x00\x12\x12\n\x0e\x43REATE_PRIVATE\x10\x01\x12\x11\n\rCREATE_PUBLIC\x10\x02\x12\x0f\n\x0b\x43REATE_TEMP\x10\x03\"Q\n\nCreateMode\x12\x12\n\x0e\x43REATE_DEFAULT\x10\x00\x12\x15\n\x11\x43REATE_OR_REPLACE\x10\x01\x12\x18\n\x14\x43REATE_IF_NOT_EXISTS\x10\x02\"_\n\x0bSqlSecurity\x12\x1c\n\x18SQL_SECURITY_UNSPECIFIED\x10\x00\x12\x18\n\x14SQL_SECURITY_DEFINER\x10\x01\x12\x18\n\x14SQL_SECURITY_INVOKER\x10\x02\"\xbe\x01\n\x10\x44\x65terminismLevel\x12\x1b\n\x17\x44\x45TERMINISM_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x44\x45TERMINISM_DETERMINISTIC\x10\x01\x12!\n\x1d\x44\x45TERMINISM_NOT_DETERMINISTIC\x10\x02\x12\x19\n\x15\x44\x45TERMINISM_IMMUTABLE\x10\x03\x12\x16\n\x12\x44\x45TERMINISM_STABLE\x10\x04\x12\x18\n\x14\x44\x45TERMINISM_VOLATILE\x10\x05\"\x8e\x01\n ResolvedGeneratedColumnInfoEnums\"=\n\nStoredMode\x12\x0e\n\nNON_STORED\x10\x00\x12\n\n\x06STORED\x10\x01\x12\x13\n\x0fSTORED_VOLATILE\x10\x02\"+\n\rGeneratedMode\x12\n\n\x06\x41LWAYS\x10\x00\x12\x0e\n\nBY_DEFAULT\x10\x01\"Y\n\x15ResolvedDropStmtEnums\"@\n\x08\x44ropMode\x12\x19\n\x15\x44ROP_MODE_UNSPECIFIED\x10\x00\x12\x0c\n\x08RESTRICT\x10\x01\x12\x0b\n\x07\x43\x41SCADE\x10\x02\"h\n\x16ResolvedBeginStmtEnums\"N\n\rReadWriteMode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x12\n\x0eMODE_READ_ONLY\x10\x01\x12\x13\n\x0fMODE_READ_WRITE\x10\x02\"<\n\x18ResolvedWindowFrameEnums\" \n\tFrameUnit\x12\x08\n\x04ROWS\x10\x00\x12\t\n\x05RANGE\x10\x01\"\x9d\x01\n\x1cResolvedWindowFrameExprEnums\"}\n\x0c\x42oundaryType\x12\x17\n\x13UNBOUNDED_PRECEDING\x10\x00\x12\x14\n\x10OFFSET_PRECEDING\x10\x01\x12\x0f\n\x0b\x43URRENT_ROW\x10\x02\x12\x14\n\x10OFFSET_FOLLOWING\x10\x03\x12\x17\n\x13UNBOUNDED_FOLLOWING\x10\x04\"c\n\x17ResolvedInsertStmtEnums\"H\n\nInsertMode\x12\x0c\n\x08OR_ERROR\x10\x00\x12\r\n\tOR_IGNORE\x10\x01\x12\x0e\n\nOR_REPLACE\x10\x02\x12\r\n\tOR_UPDATE\x10\x03\"\x9a\x01\n\x16ResolvedMergeWhenEnums\"N\n\tMatchType\x12\x0b\n\x07MATCHED\x10\x00\x12\x19\n\x15NOT_MATCHED_BY_SOURCE\x10\x01\x12\x19\n\x15NOT_MATCHED_BY_TARGET\x10\x02\"0\n\nActionType\x12\n\n\x06INSERT\x10\x00\x12\n\n\x06UPDATE\x10\x01\x12\n\n\x06\x44\x45LETE\x10\x02\"J\n\x1dResolvedOnConflictClauseEnums\")\n\x0e\x43onflictAction\x12\x0b\n\x07NOTHING\x10\x00\x12\n\n\x06UPDATE\x10\x01\"X\n\x18ResolvedArgumentDefEnums\"<\n\x0c\x41rgumentKind\x12\n\n\x06SCALAR\x10\x00\x12\r\n\tAGGREGATE\x10\x01\x12\x11\n\rNOT_AGGREGATE\x10\x02\"Y\n\x1dResolvedFunctionCallBaseEnums\"8\n\tErrorMode\x12\x16\n\x12\x44\x45\x46\x41ULT_ERROR_MODE\x10\x00\x12\x13\n\x0fSAFE_ERROR_MODE\x10\x01\"\x80\x01\n&ResolvedNonScalarFunctionCallBaseEnums\"V\n\x14NullHandlingModifier\x12\x19\n\x15\x44\x45\x46\x41ULT_NULL_HANDLING\x10\x00\x12\x10\n\x0cIGNORE_NULLS\x10\x01\x12\x11\n\rRESPECT_NULLS\x10\x02\"[\n$ResolvedAggregateHavingModifierEnums\"3\n\x12HavingModifierKind\x12\x0b\n\x07INVALID\x10\x00\x12\x07\n\x03MAX\x10\x01\x12\x07\n\x03MIN\x10\x02\"W\n\x16ResolvedStatementEnums\"=\n\x0cObjectAccess\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\x12\x0e\n\nREAD_WRITE\x10\x03\"w\n\x17ResolvedImportStmtEnums\"\\\n\nImportKind\x12\n\n\x06MODULE\x10\x00\x12\t\n\x05PROTO\x10\x01\x12\x37\n*__ImportKind__switch_must_have_a_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\"\x99\x01\n\x17ResolvedForeignKeyEnums\"3\n\tMatchMode\x12\n\n\x06SIMPLE\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x12\x10\n\x0cNOT_DISTINCT\x10\x02\"I\n\x0f\x41\x63tionOperation\x12\r\n\tNO_ACTION\x10\x00\x12\x0c\n\x08RESTRICT\x10\x01\x12\x0b\n\x07\x43\x41SCADE\x10\x02\x12\x0c\n\x08SET_NULL\x10\x03\"T\n\x1cResolvedAuxLoadDataStmtEnums\"4\n\rInsertionMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x41PPEND\x10\x01\x12\r\n\tOVERWRITE\x10\x02\"~\n\x1fResolvedMatchRecognizeScanEnums\"[\n\x12\x41\x66terMatchSkipMode\x12%\n!AFTER_MATCH_SKIP_MODE_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x45ND_OF_MATCH\x10\x01\x12\x0c\n\x08NEXT_ROW\x10\x02\"\\\n(ResolvedMatchRecognizePatternAnchorEnums\"0\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\t\n\x05START\x10\x01\x12\x07\n\x03\x45ND\x10\x02\"\x8e\x01\n+ResolvedMatchRecognizePatternOperationEnums\"_\n\"MatchRecognizePatternOperationType\x12\x1e\n\x1aOPERATION_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x43ONCAT\x10\x01\x12\r\n\tALTERNATE\x10\x02\"q\n\x1fResolvedGraphLabelNaryExprEnums\"N\n\x12GraphLogicalOpType\x12\x1e\n\x1aOPERATION_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03NOT\x10\x01\x12\x07\n\x03\x41ND\x10\x02\x12\x06\n\x02OR\x10\x03\"M\n\x1aResolvedGraphEdgeScanEnums\"/\n\x0f\x45\x64geOrientation\x12\x07\n\x03\x41NY\x10\x00\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02\"q\n\x1aResolvedGraphPathModeEnums\"S\n\x08PathMode\x12\x19\n\x15PATH_MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04WALK\x10\x01\x12\t\n\x05TRAIL\x10\x02\x12\n\n\x06SIMPLE\x10\x03\x12\x0b\n\x07\x41\x43YCLIC\x10\x04\"\x8a\x01\n\"ResolvedGraphPathSearchPrefixEnums\"d\n\x14PathSearchPrefixType\x12\'\n#PATH_SEARCH_PREFIX_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41NY\x10\x01\x12\x0c\n\x08SHORTEST\x10\x02\x12\x0c\n\x08\x43HEAPEST\x10\x03\"`\n\x1aResolvedDropIndexStmtEnums\"B\n\tIndexType\x12\x11\n\rINDEX_DEFAULT\x10\x00\x12\x10\n\x0cINDEX_SEARCH\x10\x01\x12\x10\n\x0cINDEX_VECTOR\x10\x02\"Y\n\x13ResolvedOptionEnums\"B\n\x0c\x41ssignmentOp\x12\x12\n\x0e\x44\x45\x46\x41ULT_ASSIGN\x10\x00\x12\x0e\n\nADD_ASSIGN\x10\x01\x12\x0e\n\nSUB_ASSIGN\x10\x02\"7\n\x15ResolvedLockModeEnums\"\x1e\n\x10LockStrengthType\x12\n\n\x06UPDATE\x10\x00\"f\n\x1bResolvedAlterIndexStmtEnums\"G\n\x0e\x41lterIndexType\x12\x11\n\rINDEX_DEFAULT\x10\x00\x12\x10\n\x0cINDEX_SEARCH\x10\x01\x12\x10\n\x0cINDEX_VECTOR\x10\x02\"n\n\x1cResolvedUpdateFieldItemEnums\"N\n\tOperation\x12\x11\n\rUPDATE_SINGLE\x10\x00\x12\x0f\n\x0bUPDATE_MANY\x10\x01\x12\x1d\n\x19UPDATE_SINGLE_NO_CREATION\x10\x02\x42;\n\x1e\x63om.google.zetasql.resolvedastB\x17ZetaSQLResolvedASTEnumsP\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.resolved_ast.resolved_ast_enums_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.google.zetasql.resolvedastB\027ZetaSQLResolvedASTEnumsP\001'
  _globals['_RESOLVEDSUBQUERYEXPRENUMS']._serialized_start=59
  _globals['_RESOLVEDSUBQUERYEXPRENUMS']._serialized_end=209
  _globals['_RESOLVEDSUBQUERYEXPRENUMS_SUBQUERYTYPE']._serialized_start=88
  _globals['_RESOLVEDSUBQUERYEXPRENUMS_SUBQUERYTYPE']._serialized_end=209
  _globals['_RESOLVEDJOINSCANENUMS']._serialized_start=211
  _globals['_RESOLVEDJOINSCANENUMS']._serialized_end=288
  _globals['_RESOLVEDJOINSCANENUMS_JOINTYPE']._serialized_start=236
  _globals['_RESOLVEDJOINSCANENUMS_JOINTYPE']._serialized_end=288
  _globals['_RESOLVEDSETOPERATIONSCANENUMS']._serialized_start=291
  _globals['_RESOLVEDSETOPERATIONSCANENUMS']._serialized_end=627
  _globals['_RESOLVEDSETOPERATIONSCANENUMS_SETOPERATIONTYPE']._serialized_start=325
  _globals['_RESOLVEDSETOPERATIONSCANENUMS_SETOPERATIONTYPE']._serialized_end=458
  _globals['_RESOLVEDSETOPERATIONSCANENUMS_SETOPERATIONCOLUMNMATCHMODE']._serialized_start=460
  _globals['_RESOLVEDSETOPERATIONSCANENUMS_SETOPERATIONCOLUMNMATCHMODE']._serialized_end=547
  _globals['_RESOLVEDSETOPERATIONSCANENUMS_SETOPERATIONCOLUMNPROPAGATIONMODE']._serialized_start=549
  _globals['_RESOLVEDSETOPERATIONSCANENUMS_SETOPERATIONCOLUMNPROPAGATIONMODE']._serialized_end=627
  _globals['_RESOLVEDRECURSIVESCANENUMS']._serialized_start=629
  _globals['_RESOLVEDRECURSIVESCANENUMS']._serialized_end=721
  _globals['_RESOLVEDRECURSIVESCANENUMS_RECURSIVESETOPERATIONTYPE']._serialized_start=659
  _globals['_RESOLVEDRECURSIVESCANENUMS_RECURSIVESETOPERATIONTYPE']._serialized_end=721
  _globals['_RESOLVEDSAMPLESCANENUMS']._serialized_start=723
  _globals['_RESOLVEDSAMPLESCANENUMS']._serialized_end=785
  _globals['_RESOLVEDSAMPLESCANENUMS_SAMPLEUNIT']._serialized_start=750
  _globals['_RESOLVEDSAMPLESCANENUMS_SAMPLEUNIT']._serialized_end=785
  _globals['_RESOLVEDORDERBYITEMENUMS']._serialized_start=787
  _globals['_RESOLVEDORDERBYITEMENUMS']._serialized_end=886
  _globals['_RESOLVEDORDERBYITEMENUMS_NULLORDERMODE']._serialized_start=815
  _globals['_RESOLVEDORDERBYITEMENUMS_NULLORDERMODE']._serialized_end=886
  _globals['_RESOLVEDCREATESTATEMENTENUMS']._serialized_start=889
  _globals['_RESOLVEDCREATESTATEMENTENUMS']._serialized_end=1389
  _globals['_RESOLVEDCREATESTATEMENTENUMS_CREATESCOPE']._serialized_start=921
  _globals['_RESOLVEDCREATESTATEMENTENUMS_CREATESCOPE']._serialized_end=1016
  _globals['_RESOLVEDCREATESTATEMENTENUMS_CREATEMODE']._serialized_start=1018
  _globals['_RESOLVEDCREATESTATEMENTENUMS_CREATEMODE']._serialized_end=1099
  _globals['_RESOLVEDCREATESTATEMENTENUMS_SQLSECURITY']._serialized_start=1101
  _globals['_RESOLVEDCREATESTATEMENTENUMS_SQLSECURITY']._serialized_end=1196
  _globals['_RESOLVEDCREATESTATEMENTENUMS_DETERMINISMLEVEL']._serialized_start=1199
  _globals['_RESOLVEDCREATESTATEMENTENUMS_DETERMINISMLEVEL']._serialized_end=1389
  _globals['_RESOLVEDGENERATEDCOLUMNINFOENUMS']._serialized_start=1392
  _globals['_RESOLVEDGENERATEDCOLUMNINFOENUMS']._serialized_end=1534
  _globals['_RESOLVEDGENERATEDCOLUMNINFOENUMS_STOREDMODE']._serialized_start=1428
  _globals['_RESOLVEDGENERATEDCOLUMNINFOENUMS_STOREDMODE']._serialized_end=1489
  _globals['_RESOLVEDGENERATEDCOLUMNINFOENUMS_GENERATEDMODE']._serialized_start=1491
  _globals['_RESOLVEDGENERATEDCOLUMNINFOENUMS_GENERATEDMODE']._serialized_end=1534
  _globals['_RESOLVEDDROPSTMTENUMS']._serialized_start=1536
  _globals['_RESOLVEDDROPSTMTENUMS']._serialized_end=1625
  _globals['_RESOLVEDDROPSTMTENUMS_DROPMODE']._serialized_start=1561
  _globals['_RESOLVEDDROPSTMTENUMS_DROPMODE']._serialized_end=1625
  _globals['_RESOLVEDBEGINSTMTENUMS']._serialized_start=1627
  _globals['_RESOLVEDBEGINSTMTENUMS']._serialized_end=1731
  _globals['_RESOLVEDBEGINSTMTENUMS_READWRITEMODE']._serialized_start=1653
  _globals['_RESOLVEDBEGINSTMTENUMS_READWRITEMODE']._serialized_end=1731
  _globals['_RESOLVEDWINDOWFRAMEENUMS']._serialized_start=1733
  _globals['_RESOLVEDWINDOWFRAMEENUMS']._serialized_end=1793
  _globals['_RESOLVEDWINDOWFRAMEENUMS_FRAMEUNIT']._serialized_start=1761
  _globals['_RESOLVEDWINDOWFRAMEENUMS_FRAMEUNIT']._serialized_end=1793
  _globals['_RESOLVEDWINDOWFRAMEEXPRENUMS']._serialized_start=1796
  _globals['_RESOLVEDWINDOWFRAMEEXPRENUMS']._serialized_end=1953
  _globals['_RESOLVEDWINDOWFRAMEEXPRENUMS_BOUNDARYTYPE']._serialized_start=1828
  _globals['_RESOLVEDWINDOWFRAMEEXPRENUMS_BOUNDARYTYPE']._serialized_end=1953
  _globals['_RESOLVEDINSERTSTMTENUMS']._serialized_start=1955
  _globals['_RESOLVEDINSERTSTMTENUMS']._serialized_end=2054
  _globals['_RESOLVEDINSERTSTMTENUMS_INSERTMODE']._serialized_start=1982
  _globals['_RESOLVEDINSERTSTMTENUMS_INSERTMODE']._serialized_end=2054
  _globals['_RESOLVEDMERGEWHENENUMS']._serialized_start=2057
  _globals['_RESOLVEDMERGEWHENENUMS']._serialized_end=2211
  _globals['_RESOLVEDMERGEWHENENUMS_MATCHTYPE']._serialized_start=2083
  _globals['_RESOLVEDMERGEWHENENUMS_MATCHTYPE']._serialized_end=2161
  _globals['_RESOLVEDMERGEWHENENUMS_ACTIONTYPE']._serialized_start=2163
  _globals['_RESOLVEDMERGEWHENENUMS_ACTIONTYPE']._serialized_end=2211
  _globals['_RESOLVEDONCONFLICTCLAUSEENUMS']._serialized_start=2213
  _globals['_RESOLVEDONCONFLICTCLAUSEENUMS']._serialized_end=2287
  _globals['_RESOLVEDONCONFLICTCLAUSEENUMS_CONFLICTACTION']._serialized_start=2246
  _globals['_RESOLVEDONCONFLICTCLAUSEENUMS_CONFLICTACTION']._serialized_end=2287
  _globals['_RESOLVEDARGUMENTDEFENUMS']._serialized_start=2289
  _globals['_RESOLVEDARGUMENTDEFENUMS']._serialized_end=2377
  _globals['_RESOLVEDARGUMENTDEFENUMS_ARGUMENTKIND']._serialized_start=2317
  _globals['_RESOLVEDARGUMENTDEFENUMS_ARGUMENTKIND']._serialized_end=2377
  _globals['_RESOLVEDFUNCTIONCALLBASEENUMS']._serialized_start=2379
  _globals['_RESOLVEDFUNCTIONCALLBASEENUMS']._serialized_end=2468
  _globals['_RESOLVEDFUNCTIONCALLBASEENUMS_ERRORMODE']._serialized_start=2412
  _globals['_RESOLVEDFUNCTIONCALLBASEENUMS_ERRORMODE']._serialized_end=2468
  _globals['_RESOLVEDNONSCALARFUNCTIONCALLBASEENUMS']._serialized_start=2471
  _globals['_RESOLVEDNONSCALARFUNCTIONCALLBASEENUMS']._serialized_end=2599
  _globals['_RESOLVEDNONSCALARFUNCTIONCALLBASEENUMS_NULLHANDLINGMODIFIER']._serialized_start=2513
  _globals['_RESOLVEDNONSCALARFUNCTIONCALLBASEENUMS_NULLHANDLINGMODIFIER']._serialized_end=2599
  _globals['_RESOLVEDAGGREGATEHAVINGMODIFIERENUMS']._serialized_start=2601
  _globals['_RESOLVEDAGGREGATEHAVINGMODIFIERENUMS']._serialized_end=2692
  _globals['_RESOLVEDAGGREGATEHAVINGMODIFIERENUMS_HAVINGMODIFIERKIND']._serialized_start=2641
  _globals['_RESOLVEDAGGREGATEHAVINGMODIFIERENUMS_HAVINGMODIFIERKIND']._serialized_end=2692
  _globals['_RESOLVEDSTATEMENTENUMS']._serialized_start=2694
  _globals['_RESOLVEDSTATEMENTENUMS']._serialized_end=2781
  _globals['_RESOLVEDSTATEMENTENUMS_OBJECTACCESS']._serialized_start=2720
  _globals['_RESOLVEDSTATEMENTENUMS_OBJECTACCESS']._serialized_end=2781
  _globals['_RESOLVEDIMPORTSTMTENUMS']._serialized_start=2783
  _globals['_RESOLVEDIMPORTSTMTENUMS']._serialized_end=2902
  _globals['_RESOLVEDIMPORTSTMTENUMS_IMPORTKIND']._serialized_start=2810
  _globals['_RESOLVEDIMPORTSTMTENUMS_IMPORTKIND']._serialized_end=2902
  _globals['_RESOLVEDFOREIGNKEYENUMS']._serialized_start=2905
  _globals['_RESOLVEDFOREIGNKEYENUMS']._serialized_end=3058
  _globals['_RESOLVEDFOREIGNKEYENUMS_MATCHMODE']._serialized_start=2932
  _globals['_RESOLVEDFOREIGNKEYENUMS_MATCHMODE']._serialized_end=2983
  _globals['_RESOLVEDFOREIGNKEYENUMS_ACTIONOPERATION']._serialized_start=2985
  _globals['_RESOLVEDFOREIGNKEYENUMS_ACTIONOPERATION']._serialized_end=3058
  _globals['_RESOLVEDAUXLOADDATASTMTENUMS']._serialized_start=3060
  _globals['_RESOLVEDAUXLOADDATASTMTENUMS']._serialized_end=3144
  _globals['_RESOLVEDAUXLOADDATASTMTENUMS_INSERTIONMODE']._serialized_start=3092
  _globals['_RESOLVEDAUXLOADDATASTMTENUMS_INSERTIONMODE']._serialized_end=3144
  _globals['_RESOLVEDMATCHRECOGNIZESCANENUMS']._serialized_start=3146
  _globals['_RESOLVEDMATCHRECOGNIZESCANENUMS']._serialized_end=3272
  _globals['_RESOLVEDMATCHRECOGNIZESCANENUMS_AFTERMATCHSKIPMODE']._serialized_start=3181
  _globals['_RESOLVEDMATCHRECOGNIZESCANENUMS_AFTERMATCHSKIPMODE']._serialized_end=3272
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNANCHORENUMS']._serialized_start=3274
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNANCHORENUMS']._serialized_end=3366
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNANCHORENUMS_MODE']._serialized_start=3318
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNANCHORENUMS_MODE']._serialized_end=3366
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNOPERATIONENUMS']._serialized_start=3369
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNOPERATIONENUMS']._serialized_end=3511
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNOPERATIONENUMS_MATCHRECOGNIZEPATTERNOPERATIONTYPE']._serialized_start=3416
  _globals['_RESOLVEDMATCHRECOGNIZEPATTERNOPERATIONENUMS_MATCHRECOGNIZEPATTERNOPERATIONTYPE']._serialized_end=3511
  _globals['_RESOLVEDGRAPHLABELNARYEXPRENUMS']._serialized_start=3513
  _globals['_RESOLVEDGRAPHLABELNARYEXPRENUMS']._serialized_end=3626
  _globals['_RESOLVEDGRAPHLABELNARYEXPRENUMS_GRAPHLOGICALOPTYPE']._serialized_start=3548
  _globals['_RESOLVEDGRAPHLABELNARYEXPRENUMS_GRAPHLOGICALOPTYPE']._serialized_end=3626
  _globals['_RESOLVEDGRAPHEDGESCANENUMS']._serialized_start=3628
  _globals['_RESOLVEDGRAPHEDGESCANENUMS']._serialized_end=3705
  _globals['_RESOLVEDGRAPHEDGESCANENUMS_EDGEORIENTATION']._serialized_start=3658
  _globals['_RESOLVEDGRAPHEDGESCANENUMS_EDGEORIENTATION']._serialized_end=3705
  _globals['_RESOLVEDGRAPHPATHMODEENUMS']._serialized_start=3707
  _globals['_RESOLVEDGRAPHPATHMODEENUMS']._serialized_end=3820
  _globals['_RESOLVEDGRAPHPATHMODEENUMS_PATHMODE']._serialized_start=3737
  _globals['_RESOLVEDGRAPHPATHMODEENUMS_PATHMODE']._serialized_end=3820
  _globals['_RESOLVEDGRAPHPATHSEARCHPREFIXENUMS']._serialized_start=3823
  _globals['_RESOLVEDGRAPHPATHSEARCHPREFIXENUMS']._serialized_end=3961
  _globals['_RESOLVEDGRAPHPATHSEARCHPREFIXENUMS_PATHSEARCHPREFIXTYPE']._serialized_start=3861
  _globals['_RESOLVEDGRAPHPATHSEARCHPREFIXENUMS_PATHSEARCHPREFIXTYPE']._serialized_end=3961
  _globals['_RESOLVEDDROPINDEXSTMTENUMS']._serialized_start=3963
  _globals['_RESOLVEDDROPINDEXSTMTENUMS']._serialized_end=4059
  _globals['_RESOLVEDDROPINDEXSTMTENUMS_INDEXTYPE']._serialized_start=3993
  _globals['_RESOLVEDDROPINDEXSTMTENUMS_INDEXTYPE']._serialized_end=4059
  _globals['_RESOLVEDOPTIONENUMS']._serialized_start=4061
  _globals['_RESOLVEDOPTIONENUMS']._serialized_end=4150
  _globals['_RESOLVEDOPTIONENUMS_ASSIGNMENTOP']._serialized_start=4084
  _globals['_RESOLVEDOPTIONENUMS_ASSIGNMENTOP']._serialized_end=4150
  _globals['_RESOLVEDLOCKMODEENUMS']._serialized_start=4152
  _globals['_RESOLVEDLOCKMODEENUMS']._serialized_end=4207
  _globals['_RESOLVEDLOCKMODEENUMS_LOCKSTRENGTHTYPE']._serialized_start=4177
  _globals['_RESOLVEDLOCKMODEENUMS_LOCKSTRENGTHTYPE']._serialized_end=4207
  _globals['_RESOLVEDALTERINDEXSTMTENUMS']._serialized_start=4209
  _globals['_RESOLVEDALTERINDEXSTMTENUMS']._serialized_end=4311
  _globals['_RESOLVEDALTERINDEXSTMTENUMS_ALTERINDEXTYPE']._serialized_start=4240
  _globals['_RESOLVEDALTERINDEXSTMTENUMS_ALTERINDEXTYPE']._serialized_end=4311
  _globals['_RESOLVEDUPDATEFIELDITEMENUMS']._serialized_start=4313
  _globals['_RESOLVEDUPDATEFIELDITEMENUMS']._serialized_end=4423
  _globals['_RESOLVEDUPDATEFIELDITEMENUMS_OPERATION']._serialized_start=4345
  _globals['_RESOLVEDUPDATEFIELDITEMENUMS_OPERATION']._serialized_end=4423
# @@protoc_insertion_point(module_scope)
